import React, { Component } from 'react';
import Fullscreen from 'react-full-screen';
import { I18nextProvider } from 'react-i18next';
import { LiveAnnouncer } from 'react-aria-live';
import { ThemeProvider, StylesProvider, createMuiTheme, jssPreset, createGenerateClassName } from '@material-ui/core/styles';
import { DndContext, DndProvider } from 'react-dnd';
import MultiBackend from 'react-dnd-multi-backend';
import HTML5toTouch from 'react-dnd-multi-backend/dist/cjs/HTML5toTouch';
import { create } from 'jss';
import rtl from 'jss-rtl';
import createI18nInstance from '../i18n';
/**
 * Allow applications to opt-out of (or provide their own) drag and drop context
 */

const MaybeDndProvider = props => {
  const dndManager = props.dndManager,
        children = props.children;

  if (dndManager === false) {
    return children;
  }

  if (dndManager === undefined) {
    return /*#__PURE__*/React.createElement(DndProvider, {
      backend: MultiBackend,
      options: HTML5toTouch
    }, children);
  }

  return /*#__PURE__*/React.createElement(DndContext.Provider, {
    value: dndManager
  }, children);
};

/**
 * This component adds viewer-specific providers.
 * @prop {Object} manifests
 */
export class AppProviders extends Component {
  /** */
  constructor(props) {
    super(props);
    this.i18n = createI18nInstance();
  }
  /**
   * Set i18n language on component mount
   */


  componentDidMount() {
    const language = this.props.language;
    this.i18n.changeLanguage(language);
  }
  /**
   * Update the i18n language if it is changed
   */


  componentDidUpdate(prevProps) {
    const language = this.props.language;

    if (prevProps.language !== language) {
      this.i18n.changeLanguage(language);
    }
  }
  /** */


  render() {
    const _this$props = this.props,
          children = _this$props.children,
          createGenerateClassNameOptions = _this$props.createGenerateClassNameOptions,
          isFullscreenEnabled = _this$props.isFullscreenEnabled,
          setWorkspaceFullscreen = _this$props.setWorkspaceFullscreen,
          theme = _this$props.theme,
          translations = _this$props.translations,
          dndManager = _this$props.dndManager;
    const generateClassName = createGenerateClassName(createGenerateClassNameOptions);
    Object.keys(translations).forEach(lng => {
      this.i18n.addResourceBundle(lng, 'translation', translations[lng], true, true);
    });
    return /*#__PURE__*/React.createElement(Fullscreen, {
      enabled: isFullscreenEnabled,
      onChange: setWorkspaceFullscreen
    }, /*#__PURE__*/React.createElement(I18nextProvider, {
      i18n: this.i18n
    }, /*#__PURE__*/React.createElement(LiveAnnouncer, null, /*#__PURE__*/React.createElement(ThemeProvider, {
      theme: createMuiTheme(theme)
    }, /*#__PURE__*/React.createElement(StylesProvider, {
      jss: create({
        plugins: [...jssPreset().plugins, rtl()]
      }),
      generateClassName: generateClassName
    }, /*#__PURE__*/React.createElement(MaybeDndProvider, {
      dndManager: dndManager
    }, children))))));
  }

}
AppProviders.defaultProps = {
  children: null,
  createGenerateClassNameOptions: {},
  dndManager: undefined,
  isFullscreenEnabled: false
};