import React, { Component } from 'react';
import clsx from 'clsx';
import Chip from '@material-ui/core/Chip';
import MenuList from '@material-ui/core/MenuList';
import MenuItem from '@material-ui/core/MenuItem';
import ListItemText from '@material-ui/core/ListItemText';
import Typography from '@material-ui/core/Typography';
import SanitizedHtml from '../containers/SanitizedHtml';
/**
 * CanvasAnnotations ~
*/

export class CanvasAnnotations extends Component {
  /**
   * constructor -
   */
  constructor(props) {
    super(props);
    this.handleClick = this.handleClick.bind(this);
    this.handleAnnotationHover = this.handleAnnotationHover.bind(this);
    this.handleAnnotationBlur = this.handleAnnotationBlur.bind(this);
  }
  /**
   * Handle click event of an annotation.
  */


  handleClick(event, annotation) {
    const _this$props = this.props,
          deselectAnnotation = _this$props.deselectAnnotation,
          selectAnnotation = _this$props.selectAnnotation,
          selectedAnnotationId = _this$props.selectedAnnotationId,
          windowId = _this$props.windowId;

    if (selectedAnnotationId === annotation.id) {
      deselectAnnotation(windowId, annotation.id);
    } else {
      selectAnnotation(windowId, annotation.id);
    }
  }
  /** */


  handleAnnotationHover(annotation) {
    const _this$props2 = this.props,
          hoverAnnotation = _this$props2.hoverAnnotation,
          windowId = _this$props2.windowId;
    hoverAnnotation(windowId, [annotation.id]);
  }
  /** */


  handleAnnotationBlur() {
    const _this$props3 = this.props,
          hoverAnnotation = _this$props3.hoverAnnotation,
          windowId = _this$props3.windowId;
    hoverAnnotation(windowId, []);
  }
  /**
   * Returns the rendered component
  */


  render() {
    const _this$props4 = this.props,
          annotations = _this$props4.annotations,
          classes = _this$props4.classes,
          index = _this$props4.index,
          label = _this$props4.label,
          selectedAnnotationId = _this$props4.selectedAnnotationId,
          t = _this$props4.t,
          totalSize = _this$props4.totalSize,
          listContainerComponent = _this$props4.listContainerComponent,
          htmlSanitizationRuleSet = _this$props4.htmlSanitizationRuleSet,
          hoveredAnnotationIds = _this$props4.hoveredAnnotationIds;
    if (annotations.length === 0) return /*#__PURE__*/React.createElement(React.Fragment, null);
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Typography, {
      className: classes.sectionHeading,
      variant: "overline"
    }, t('annotationCanvasLabel', {
      context: `${index + 1}/${totalSize}`,
      label
    })), /*#__PURE__*/React.createElement(MenuList, {
      autoFocusItem: true,
      variant: "selectedMenu"
    }, annotations.map(annotation => /*#__PURE__*/React.createElement(MenuItem, {
      button: true,
      component: listContainerComponent,
      className: clsx(classes.annotationListItem, {
        [classes.hovered]: hoveredAnnotationIds.includes(annotation.id)
      }),
      key: annotation.id,
      annotationid: annotation.id,
      selected: selectedAnnotationId === annotation.id,
      onClick: e => this.handleClick(e, annotation),
      onFocus: () => this.handleAnnotationHover(annotation),
      onBlur: this.handleAnnotationBlur,
      onMouseEnter: () => this.handleAnnotationHover(annotation),
      onMouseLeave: this.handleAnnotationBlur
    }, /*#__PURE__*/React.createElement(ListItemText, {
      primaryTypographyProps: {
        variant: 'body2'
      }
    }, /*#__PURE__*/React.createElement(SanitizedHtml, {
      ruleSet: htmlSanitizationRuleSet,
      htmlString: annotation.content
    }), /*#__PURE__*/React.createElement("div", null, annotation.tags.map(tag => /*#__PURE__*/React.createElement(Chip, {
      size: "small",
      variant: "outlined",
      label: tag,
      id: tag,
      className: classes.chip,
      key: tag.toString()
    }))))))));
  }

}
CanvasAnnotations.defaultProps = {
  annotations: [],
  classes: {},
  hoveredAnnotationIds: [],
  htmlSanitizationRuleSet: 'iiif',
  listContainerComponent: 'li',
  selectedAnnotationId: undefined
};