import React, { Component } from 'react';
import CompanionWindowRegistry from '../lib/CompanionWindowRegistry';
import CompanionWindow from '../containers/CompanionWindow';
import ErrorContent from '../containers/ErrorContent';
/**
 * Render a companion window using the appropriate component for the content
 */

export class CompanionWindowFactory extends Component {
  /** */
  constructor(props) {
    super(props);
    this.state = {};
  }
  /** */


  static getDerivedStateFromError(error) {
    // Update state so the next render will show the fallback UI.
    return {
      error,
      hasError: true
    };
  }
  /**
   * Clear the error state if the internal content changes; this is a rare
   * case, only when we reuse an existing companionWindow instance for
   * the left-anchored companion area (anti-pattern?)
   */


  componentDidUpdate(prevProps) {
    const content = this.props.content; // Typical usage (don't forget to compare props):

    if (content !== prevProps.content) {
      this.setState({
        // eslint-disable-line react/no-did-update-set-state
        error: null,
        hasError: false
      });
    }
  }
  /** */


  render() {
    const _this$props = this.props,
          content = _this$props.content,
          windowId = _this$props.windowId,
          id = _this$props.id,
          t = _this$props.t;
    const _this$state = this.state,
          error = _this$state.error,
          hasError = _this$state.hasError;

    if (hasError) {
      return /*#__PURE__*/React.createElement(CompanionWindow, {
        title: t('error'),
        windowId: windowId,
        id: id
      }, /*#__PURE__*/React.createElement(ErrorContent, {
        error: error,
        windowId: windowId,
        companionWindowId: id
      }));
    }

    const type = CompanionWindowRegistry[content];
    if (!type) return /*#__PURE__*/React.createElement(React.Fragment, null);
    return /*#__PURE__*/React.createElement(type, {
      id,
      windowId
    });
  }

}
CompanionWindowFactory.defaultProps = {
  content: null,
  t: key => key
};