function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import Backdrop from '@material-ui/core/Backdrop';
import InsertDriveFileSharpIcon from '@material-ui/icons/InsertDriveFileSharp';
import { grey } from '@material-ui/core/colors';
import { v4 as uuid } from 'uuid';
import { NativeTypes } from 'react-dnd-html5-backend';
import { useDrop } from 'react-dnd';
import { readImageMetadata } from '../lib/readImageMetadata';
/** */

export const handleDrop = (item, monitor, props) => {
  const onDrop = props.onDrop;

  if (item.urls) {
    item.urls.forEach(str => {
      const url = new URL(str);
      const manifestId = url.searchParams.get('manifest');
      const canvasId = url.searchParams.get('canvas');
      if (manifestId) onDrop({
        canvasId,
        manifestId
      }, props, monitor);
    });
  }

  if (item.files) {
    const manifestFiles = item.files.filter(f => f.type === 'application/json');
    const manifestPromises = manifestFiles.map(file => new Promise((resolve, reject) => {
      const reader = new FileReader();
      reader.addEventListener('load', () => {
        const manifestJson = reader.result;
        const manifestId = uuid();
        if (manifestJson) onDrop({
          manifestId,
          manifestJson
        }, props, monitor);
        resolve();
      });
      reader.readAsText(file);
    }));
    const imageFiles = item.files.filter(({
      type
    }) => type.startsWith('image/'));
    let imagePromise;

    if (imageFiles.length > 0) {
      const id = uuid();
      const imageData = imageFiles.map(file => readImageMetadata(file));
      imagePromise = Promise.all(imageData).then(images => {
        const manifestJson = {
          '@context': 'http://iiif.io/api/presentation/3/context.json',
          id,
          items: images.map(({
            name,
            type,
            width,
            height,
            url
          }, index) => ({
            height,
            id: `${id}/canvas/${index}`,
            items: [{
              id: `${id}/canvas/${index}/1`,
              items: [{
                body: {
                  format: type,
                  id: url,
                  type: 'Image'
                },
                height,
                id: `${id}/canvas/${index}/1/image`,
                motivation: 'painting',
                target: `${id}/canvas/${index}/1`,
                type: 'Annotation',
                width
              }],
              type: 'AnnotationPage'
            }],
            label: name,
            type: 'Canvas',
            width
          })),
          label: images[0].name,
          type: 'Manifest'
        };
        const manifestId = uuid();
        if (manifestJson) onDrop({
          manifestId,
          manifestJson
        }, props, monitor);
      });
    }

    return Promise.all([...manifestPromises, imagePromise]);
  }

  return undefined;
};
/** */

export const IIIFDropTarget = props => {
  const children = props.children,
        onDrop = props.onDrop;

  const _useDrop = useDrop({
    accept: [NativeTypes.URL, NativeTypes.FILE],
    collect: monitor => ({
      canDrop: monitor.canDrop(),
      isOver: monitor.isOver()
    }),

    /** */
    drop(item, monitor) {
      if (!onDrop) return;
      handleDrop(item, monitor, props);
    }

  }),
        _useDrop2 = _slicedToArray(_useDrop, 2),
        _useDrop2$ = _useDrop2[0],
        canDrop = _useDrop2$.canDrop,
        isOver = _useDrop2$.isOver,
        drop = _useDrop2[1];
  /**
   * Safari reports drag+drop'ed urls as both a file and uri-list
   * which gets mis-classified by react-dnd.
   */


  const hackForSafari = e => {
    if (!window.safari || !onDrop || !e.dataTransfer) return;

    if (e.dataTransfer.types.includes('Files') && e.dataTransfer.types.includes('text/uri-list')) {
      const url = e.dataTransfer.getData('text/uri-list');
      if (!url) return;
      handleDrop({
        urls: [url]
      }, null, props);
    }
  };

  const isActive = canDrop && isOver;
  return /*#__PURE__*/React.createElement("div", {
    ref: drop,
    onDrop: hackForSafari,
    style: {
      height: '100%',
      width: '100%'
    }
  }, children, /*#__PURE__*/React.createElement(Backdrop, {
    open: isActive,
    style: {
      zIndex: 9999
    }
  }, /*#__PURE__*/React.createElement(InsertDriveFileSharpIcon, {
    style: {
      color: grey[400],
      fontSize: 256
    }
  })));
};