import React, { Component } from 'react';
import Typography from '@material-ui/core/Typography';
import SanitizedHtml from '../containers/SanitizedHtml';
import ns from '../config/css-ns';
/**
 * Renders label/value pair metadata in a dl
 * @prop {object} labelValuePair
 */

export class LabelValueMetadata extends Component {
  /**
   * render
   * @return {String} - HTML markup for the component
   */
  render() {
    const _this$props = this.props,
          defaultLabel = _this$props.defaultLabel,
          labelValuePairs = _this$props.labelValuePairs;

    if (labelValuePairs.length === 0) {
      return /*#__PURE__*/React.createElement(React.Fragment, null);
    }
    /* eslint-disable react/no-array-index-key */
    // Disabling array index key for dt/dd elements as
    // they are intended to display metadata that will not
    // need to be re-rendered internally in any meaningful way


    return /*#__PURE__*/React.createElement("dl", {
      className: ns('label-value-metadata')
    }, labelValuePairs.reduce((acc, labelValuePair, i) => acc.concat([/*#__PURE__*/React.createElement(Typography, {
      component: "dt",
      key: `label-${i}`,
      variant: "subtitle2"
    }, labelValuePair.label || defaultLabel), /*#__PURE__*/React.createElement(Typography, {
      style: {
        marginBottom: '.5em',
        marginLeft: '0px'
      },
      component: "dd",
      key: `value-${i}`,
      variant: "body1"
    }, /*#__PURE__*/React.createElement(SanitizedHtml, {
      htmlString: labelValuePair.values.join(', '),
      ruleSet: "iiif"
    }))]), []));
    /* eslint-enable react/no-array-index-key */
  }

}
LabelValueMetadata.defaultProps = {
  defaultLabel: undefined
};