import React, { Component } from 'react';
import Button from '@material-ui/core/Button';
import Grid from '@material-ui/core/Grid';
import TextField from '@material-ui/core/TextField';
/**
 * Provides a form for user input of a manifest url
 * @prop {Function} fetchManifest
 */

export class ManifestForm extends Component {
  /**
   * constructor -
   */
  constructor(props) {
    super(props);
    this.state = {
      formValue: ''
    };
    this.inputRef = /*#__PURE__*/React.createRef();
    this.formSubmit = this.formSubmit.bind(this);
    this.handleCancel = this.handleCancel.bind(this);
    this.handleInputChange = this.handleInputChange.bind(this);
  }
  /**
   *
   * @param {*} prevProps
   * @param {*} prevState
   */


  componentDidUpdate() {
    const addResourcesOpen = this.props.addResourcesOpen;

    if (this.inputRef && this.inputRef.current && addResourcesOpen) {
      this.inputRef.current.focus();
    }
  }
  /**
   * Reset the form state
   */


  handleCancel() {
    const onCancel = this.props.onCancel;
    onCancel();
    this.setState({
      formValue: ''
    });
  }
  /**
   * handleInputChange - sets state based on input change.
   * @param  {Event} event
   * @private
   */


  handleInputChange(event) {
    const that = this;
    event.preventDefault();
    that.setState({
      formValue: event.target.value
    });
  }
  /**
   * formSubmit - triggers manifest update and sets lastRequested
   * @param  {Event} event
   * @private
   */


  formSubmit(event) {
    const _this$props = this.props,
          addResource = _this$props.addResource,
          onSubmit = _this$props.onSubmit;
    const formValue = this.state.formValue;
    event.preventDefault();
    onSubmit();
    addResource(formValue);
    this.setState({
      formValue: ''
    });
  }
  /**
   * render
   * @return {String} - HTML markup for the component
   */


  render() {
    const formValue = this.state.formValue;
    const _this$props2 = this.props,
          classes = _this$props2.classes,
          onCancel = _this$props2.onCancel,
          t = _this$props2.t;
    return /*#__PURE__*/React.createElement("form", {
      onSubmit: this.formSubmit
    }, /*#__PURE__*/React.createElement(Grid, {
      container: true,
      spacing: 2
    }, /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 12,
      sm: 8,
      md: 9
    }, /*#__PURE__*/React.createElement(TextField, {
      inputRef: this.inputRef,
      fullWidth: true,
      value: formValue,
      id: "manifestURL",
      type: "text",
      onChange: this.handleInputChange,
      variant: "filled",
      label: t('addManifestUrl'),
      helperText: t('addManifestUrlHelp'),
      InputLabelProps: {
        shrink: true
      },
      InputProps: {
        className: classes.input
      }
    })), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 12,
      sm: 4,
      md: 3,
      className: classes.buttons
    }, onCancel && /*#__PURE__*/React.createElement(Button, {
      onClick: this.handleCancel
    }, t('cancel')), /*#__PURE__*/React.createElement(Button, {
      id: "fetchBtn",
      type: "submit",
      variant: "contained",
      color: "primary"
    }, t('fetchManifest')))));
  }

}
ManifestForm.defaultProps = {
  classes: {},
  onCancel: null,
  onSubmit: () => {},
  t: key => key
};