import React, { Component } from 'react';
import clsx from 'clsx';
import Button from '@material-ui/core/Button';
import ListItem from '@material-ui/core/ListItem';
import ListItemText from '@material-ui/core/ListItemText';
import Typography from '@material-ui/core/Typography';
import Chip from '@material-ui/core/Chip';
import SanitizedHtml from '../containers/SanitizedHtml';
import TruncatedHit from '../lib/TruncatedHit';
import { ScrollTo } from './ScrollTo';
/** */

export class SearchHit extends Component {
  /** */
  constructor(props) {
    super(props);
    this.handleClick = this.handleClick.bind(this);
  }
  /**
   * Announce the annotation content if the component is mounted selected
   */


  componentDidMount() {
    const selected = this.props.selected;
    if (selected) this.announceHit();
  }
  /**
   * Announce hit if the hit has been selected
   */


  componentDidUpdate(prevProps) {
    const selected = this.props.selected;

    if (selected && selected !== prevProps.selected) {
      this.announceHit();
    }
  }
  /** */


  handleClick() {
    const _this$props = this.props,
          annotation = _this$props.annotation,
          annotationId = _this$props.annotationId,
          selectAnnotation = _this$props.selectAnnotation;
    if (annotation && annotationId) selectAnnotation(annotationId);
  }
  /**
   * Pass content describing the hit to the announcer prop (intended for screen readers)
   */


  announceHit() {
    const _this$props2 = this.props,
          annotation = _this$props2.annotation,
          annotationLabel = _this$props2.annotationLabel,
          announcer = _this$props2.announcer,
          canvasLabel = _this$props2.canvasLabel,
          hit = _this$props2.hit,
          index = _this$props2.index,
          t = _this$props2.t,
          total = _this$props2.total;
    if (!hit) return;
    const truncatedHit = new TruncatedHit(hit, annotation);
    announcer([t('pagination', {
      current: index + 1,
      total
    }), canvasLabel, annotationLabel, truncatedHit.before, truncatedHit.match, truncatedHit.after].join(' '));
  }
  /** */


  render() {
    const _this$props3 = this.props,
          adjacent = _this$props3.adjacent,
          annotation = _this$props3.annotation,
          annotationLabel = _this$props3.annotationLabel,
          canvasLabel = _this$props3.canvasLabel,
          classes = _this$props3.classes,
          companionWindowId = _this$props3.companionWindowId,
          containerRef = _this$props3.containerRef,
          hit = _this$props3.hit,
          focused = _this$props3.focused,
          index = _this$props3.index,
          showDetails = _this$props3.showDetails,
          selected = _this$props3.selected,
          t = _this$props3.t,
          windowSelected = _this$props3.windowSelected;
    if (focused && !selected) return null;
    const truncatedHit = focused ? hit : hit && new TruncatedHit(hit, annotation);
    const truncated = hit && truncatedHit.before !== hit.before && truncatedHit.after !== hit.after;
    const canvasLabelHtmlId = `${companionWindowId}-${index}`;
    return /*#__PURE__*/React.createElement(ScrollTo, {
      containerRef: containerRef,
      offsetTop: 96 // offset for the height of the form above
      ,
      scrollTo: windowSelected && !focused
    }, /*#__PURE__*/React.createElement(ListItem, {
      className: clsx(classes.listItem, {
        [classes.adjacent]: adjacent,
        [classes.selected]: selected,
        [classes.focused]: focused,
        [classes.windowSelected]: windowSelected
      }),
      button: !selected,
      component: "li",
      onClick: this.handleClick,
      selected: selected
    }, /*#__PURE__*/React.createElement(ListItemText, {
      primaryTypographyProps: {
        variant: 'body1'
      }
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "subtitle2",
      className: classes.subtitle
    }, /*#__PURE__*/React.createElement(Chip, {
      component: "span",
      label: index + 1,
      className: classes.hitCounter
    }), /*#__PURE__*/React.createElement("span", {
      id: canvasLabelHtmlId
    }, canvasLabel)), annotationLabel && /*#__PURE__*/React.createElement(Typography, {
      variant: "subtitle2"
    }, annotationLabel), hit && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(SanitizedHtml, {
      ruleSet: "iiif",
      htmlString: truncatedHit.before
    }), ' ', /*#__PURE__*/React.createElement("strong", null, /*#__PURE__*/React.createElement(SanitizedHtml, {
      ruleSet: "iiif",
      htmlString: truncatedHit.match
    })), ' ', /*#__PURE__*/React.createElement(SanitizedHtml, {
      ruleSet: "iiif",
      htmlString: truncatedHit.after
    }), ' ', truncated && !focused && /*#__PURE__*/React.createElement(Button, {
      className: classes.inlineButton,
      onClick: showDetails,
      color: "secondary",
      size: "small",
      "aria-describedby": canvasLabelHtmlId
    }, t('more'))), !hit && annotation && /*#__PURE__*/React.createElement(SanitizedHtml, {
      ruleSet: "iiif",
      htmlString: annotation.chars
    }))));
  }

}
SearchHit.defaultProps = {
  adjacent: false,
  annotation: undefined,
  annotationId: undefined,
  annotationLabel: undefined,
  canvasLabel: undefined,
  classes: {},
  companionWindowId: undefined,
  containerRef: undefined,
  focused: false,
  hit: undefined,
  index: undefined,
  selectAnnotation: () => {},
  selected: false,
  showDetails: () => {},
  t: k => k,
  total: undefined,
  windowSelected: false
};