import React, { Component } from 'react';
import TreeView from '@material-ui/lab/TreeView';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import ChevronRightIcon from '@material-ui/icons/ChevronRight';
import TreeItem from '@material-ui/lab/TreeItem';
import clsx from 'clsx';
import { ScrollTo } from './ScrollTo';
/** */

function getStartCanvasId(node) {
  const jsonld = node.data.__jsonld; // eslint-disable-line no-underscore-dangle

  if (jsonld.startCanvas && typeof jsonld.startCanvas === 'string') {
    return jsonld.startCanvas;
  }

  if (jsonld.start) {
    if (jsonld.start.type === 'Canvas' && typeof jsonld.start.id === 'string') {
      return jsonld.start.id;
    }

    if (jsonld.start.type === 'SpecificResource' && typeof jsonld.start.source === 'string') {
      return jsonld.start.source;
    }
  }

  return node.data.getCanvasIds()[0];
}
/** */


export class SidebarIndexTableOfContents extends Component {
  /** */
  handleKeyPressed(event, node) {
    const _this$props = this.props,
          expandedNodeIds = _this$props.expandedNodeIds,
          toggleNode = _this$props.toggleNode;

    if (event.key === 'Enter' || event.key === ' ' || event.key === 'Spacebar') {
      this.selectTreeItem(node);
    }

    if (event.key === 'ArrowLeft' && expandedNodeIds.indexOf(node.id) !== -1 || event.key === 'ArrowRight' && expandedNodeIds.indexOf(node.id) === -1 && node.nodes.length > 0) {
      toggleNode(node.id);
    }
  }
  /** */


  selectTreeItem(node) {
    const _this$props2 = this.props,
          setCanvas = _this$props2.setCanvas,
          toggleNode = _this$props2.toggleNode,
          windowId = _this$props2.windowId;

    if (node.nodes.length > 0) {
      toggleNode(node.id);
    } // Do not select if there are no canvases listed or it has children


    if (!node.data.getCanvasIds() || node.data.getCanvasIds().length === 0 || node.nodes.length > 0) {
      return;
    }

    const target = getStartCanvasId(node);
    const canvasId = target.indexOf('#') === -1 ? target : target.substr(0, target.indexOf('#'));
    setCanvas(windowId, canvasId);
  }
  /** */


  buildTreeItems(nodes, visibleNodeIds, containerRef, nodeIdToScrollTo) {
    const classes = this.props.classes;

    if (!nodes) {
      return null;
    }

    return nodes.map(node => /*#__PURE__*/React.createElement(ScrollTo, {
      containerRef: containerRef,
      key: `${node.id}-scroll`,
      offsetTop: 96 // offset for the height of the form above
      ,
      scrollTo: nodeIdToScrollTo === node.id
    }, /*#__PURE__*/React.createElement(TreeItem, {
      key: node.id,
      nodeId: node.id,
      classes: {
        content: classes.content,
        group: classes.group,
        label: classes.label,
        root: classes.treeItemRoot,
        selected: classes.selected
      },
      label: /*#__PURE__*/React.createElement("div", {
        className: clsx({
          [classes.visibleNode]: visibleNodeIds.indexOf(node.id) !== -1
        })
      }, node.label),
      onClick: () => this.selectTreeItem(node),
      onKeyDown: e => this.handleKeyPressed(e, node)
    }, node.nodes && node.nodes.length > 0 ? this.buildTreeItems(node.nodes, visibleNodeIds, containerRef, nodeIdToScrollTo) : null)));
  }
  /** */


  render() {
    const _this$props3 = this.props,
          classes = _this$props3.classes,
          treeStructure = _this$props3.treeStructure,
          visibleNodeIds = _this$props3.visibleNodeIds,
          expandedNodeIds = _this$props3.expandedNodeIds,
          containerRef = _this$props3.containerRef,
          nodeIdToScrollTo = _this$props3.nodeIdToScrollTo;

    if (!treeStructure) {
      return /*#__PURE__*/React.createElement(React.Fragment, null);
    }

    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TreeView, {
      className: classes.root,
      defaultCollapseIcon: /*#__PURE__*/React.createElement(ExpandMoreIcon, {
        color: "action"
      }),
      defaultExpandIcon: /*#__PURE__*/React.createElement(ChevronRightIcon, {
        color: "action"
      }),
      defaultEndIcon: /*#__PURE__*/React.createElement(React.Fragment, null),
      expanded: expandedNodeIds
    }, this.buildTreeItems(treeStructure.nodes, visibleNodeIds, containerRef, nodeIdToScrollTo)));
  }

}