import React, { Component } from 'react';
import Paper from '@material-ui/core/Paper';
import AutoSizer from 'react-virtualized-auto-sizer';
import { VariableSizeList as List } from 'react-window';
import classNames from 'classnames';
import CanvasWorld from '../lib/CanvasWorld';
import ThumbnailCanvasGrouping from '../containers/ThumbnailCanvasGrouping';
import ns from '../config/css-ns';
/**
 */

export class ThumbnailNavigation extends Component {
  /**
   */
  constructor(props) {
    super(props);
    this.scrollbarSize = 15;
    this.spacing = 8; // 2 * (2px margin + 2px border + 2px padding + 2px padding)

    this.calculateScaledSize = this.calculateScaledSize.bind(this);
    this.itemCount = this.itemCount.bind(this);
    this.handleKeyUp = this.handleKeyUp.bind(this);
    this.nextCanvas = this.nextCanvas.bind(this);
    this.previousCanvas = this.previousCanvas.bind(this);
    this.gridRef = /*#__PURE__*/React.createRef();
  }
  /**
   * If the view has changed and the thumbnailNavigation is open, recompute all
   * of the grids
   */


  componentDidUpdate(prevProps) {
    const _this$props = this.props,
          canvasIndex = _this$props.canvasIndex,
          position = _this$props.position,
          view = _this$props.view;

    if (prevProps.view !== view && position !== 'off') {
      this.gridRef.current.resetAfterIndex(0);
    }

    if (prevProps.canvasIndex !== canvasIndex) {
      let index = canvasIndex;
      if (view === 'book') index = Math.ceil(index / 2);
      this.gridRef.current.scrollToItem(index, 'center');
    }
  }
  /** */


  handleKeyUp(e) {
    const position = this.props.position;
    let nextKey = 'ArrowRight';
    let previousKey = 'ArrowLeft';

    if (position === 'far-right') {
      nextKey = 'ArrowDown';
      previousKey = 'ArrowUp';
    }

    switch (e.key) {
      case nextKey:
        this.nextCanvas();
        break;

      case previousKey:
        this.previousCanvas();
        break;

      default:
        break;
    }
  }
  /**
   * When on right, row height
   * When on bottom, column width
   */


  calculateScaledSize(index) {
    const _this$props2 = this.props,
          thumbnailNavigation = _this$props2.thumbnailNavigation,
          canvasGroupings = _this$props2.canvasGroupings,
          position = _this$props2.position;
    const canvases = canvasGroupings[index];
    const world = new CanvasWorld(canvases);
    const bounds = world.worldBounds();

    switch (position) {
      case 'far-right':
        {
          const calc = Math.floor(this.calculatingWidth(canvases.length) * bounds[3] / bounds[2]);
          if (!Number.isInteger(calc)) return thumbnailNavigation.width + this.spacing;
          return calc + this.spacing;
        }
      // Default case bottom

      default:
        {
          if (bounds[3] === 0) return thumbnailNavigation.width + this.spacing;
          const calc = Math.ceil((thumbnailNavigation.height - this.scrollbarSize - this.spacing - 4) * bounds[2] / bounds[3]);
          return calc;
        }
    }
  }
  /** */


  calculatingWidth(canvasesLength) {
    const thumbnailNavigation = this.props.thumbnailNavigation;

    if (canvasesLength === 1) {
      return thumbnailNavigation.width;
    }

    return thumbnailNavigation.width * 2;
  }
  /** */


  rightWidth() {
    const _this$props3 = this.props,
          view = _this$props3.view,
          thumbnailNavigation = _this$props3.thumbnailNavigation;

    switch (view) {
      case 'book':
        return thumbnailNavigation.width * 2;

      default:
        return thumbnailNavigation.width;
    }
  }
  /** */


  style() {
    const _this$props4 = this.props,
          position = _this$props4.position,
          thumbnailNavigation = _this$props4.thumbnailNavigation;

    switch (position) {
      case 'far-right':
        return {
          height: '100%',
          minHeight: 0,
          width: `${this.rightWidth() + this.scrollbarSize + this.spacing}px`
        };
      // Default case bottom

      default:
        return {
          height: `${thumbnailNavigation.height}px`,
          width: '100%'
        };
    }
  }
  /** */


  areaHeight(height) {
    const _this$props5 = this.props,
          position = _this$props5.position,
          thumbnailNavigation = _this$props5.thumbnailNavigation;

    switch (position) {
      case 'far-right':
        return height;
      // Default case bottom

      default:
        return thumbnailNavigation.height;
    }
  }
  /** */


  itemCount() {
    const canvasGroupings = this.props.canvasGroupings;
    return canvasGroupings.length;
  }
  /**
   */


  nextCanvas() {
    const _this$props6 = this.props,
          hasNextCanvas = _this$props6.hasNextCanvas,
          setNextCanvas = _this$props6.setNextCanvas;

    if (hasNextCanvas) {
      setNextCanvas();
    }
  }
  /**
   */


  previousCanvas() {
    const _this$props7 = this.props,
          hasPreviousCanvas = _this$props7.hasPreviousCanvas,
          setPreviousCanvas = _this$props7.setPreviousCanvas;

    if (hasPreviousCanvas) {
      setPreviousCanvas();
    }
  }
  /**
   * Renders things
   */


  render() {
    const _this$props8 = this.props,
          t = _this$props8.t,
          canvasGroupings = _this$props8.canvasGroupings,
          classes = _this$props8.classes,
          position = _this$props8.position,
          thumbnailNavigation = _this$props8.thumbnailNavigation,
          viewingDirection = _this$props8.viewingDirection,
          windowId = _this$props8.windowId;

    if (position === 'off') {
      return /*#__PURE__*/React.createElement(React.Fragment, null);
    }

    const htmlDir = viewingDirection === 'right-to-left' ? 'rtl' : 'ltr';
    const itemData = {
      canvasGroupings,
      height: thumbnailNavigation.height - this.spacing - this.scrollbarSize,
      position,
      windowId
    };
    return /*#__PURE__*/React.createElement(Paper, {
      className: classNames(ns('thumb-navigation'), classes.thumbNavigation),
      "aria-label": t('thumbnailNavigation'),
      square: true,
      elevation: 0,
      style: this.style(),
      tabIndex: 0,
      onKeyUp: this.handleKeyUp,
      role: "grid"
    }, /*#__PURE__*/React.createElement("div", {
      role: "row",
      style: {
        height: '100%',
        width: '100%'
      }
    }, /*#__PURE__*/React.createElement(AutoSizer, {
      defaultHeight: 100,
      defaultWidth: 400
    }, ({
      height,
      width
    }) => /*#__PURE__*/React.createElement(List, {
      direction: htmlDir,
      height: this.areaHeight(height),
      itemCount: this.itemCount(),
      itemSize: this.calculateScaledSize,
      width: width,
      layout: position === 'far-bottom' ? 'horizontal' : 'vertical',
      itemData: itemData,
      ref: this.gridRef
    }, ThumbnailCanvasGrouping))));
  }

}
ThumbnailNavigation.defaultProps = {
  hasNextCanvas: false,
  hasPreviousCanvas: false,
  setNextCanvas: () => {},
  setPreviousCanvas: () => {},
  view: undefined,
  viewingDirection: ''
};