import React, { Component } from 'react';
import cn from 'classnames';
import Paper from '@material-ui/core/Paper';
import { MosaicWindowContext } from 'react-mosaic-component/lib/contextTypes';
import ns from '../config/css-ns';
import WindowTopBar from '../containers/WindowTopBar';
import PrimaryWindow from '../containers/PrimaryWindow';
import CompanionArea from '../containers/CompanionArea';
import MinimalWindow from '../containers/MinimalWindow';
import ErrorContent from '../containers/ErrorContent';
import IIIFAuthentication from '../containers/IIIFAuthentication';
import { PluginHook } from './PluginHook';
/**
 * Represents a Window in the mirador workspace
 * @param {object} window
 */

export class Window extends Component {
  /** */
  constructor(props) {
    super(props);
    this.state = {};
  }
  /** */


  static getDerivedStateFromError(error) {
    // Update state so the next render will show the fallback UI.
    return {
      error,
      hasError: true
    };
  }
  /**
   * wrappedTopBar - will conditionally wrap a WindowTopBar for needed
   * additional functionality based on workspace type
   */


  wrappedTopBar() {
    const _this$props = this.props,
          windowId = _this$props.windowId,
          workspaceType = _this$props.workspaceType,
          windowDraggable = _this$props.windowDraggable;
    const topBar = /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(WindowTopBar, {
      windowId: windowId,
      windowDraggable: windowDraggable
    }), /*#__PURE__*/React.createElement(IIIFAuthentication, {
      windowId: windowId
    }));

    if (workspaceType === 'mosaic' && windowDraggable) {
      const mosaicWindowActions = this.context.mosaicWindowActions;
      return mosaicWindowActions.connectDragSource(topBar);
    }

    return topBar;
  }
  /**
   * Renders things
   */


  render() {
    const _this$props2 = this.props,
          focusWindow = _this$props2.focusWindow,
          label = _this$props2.label,
          isFetching = _this$props2.isFetching,
          maximized = _this$props2.maximized,
          sideBarOpen = _this$props2.sideBarOpen,
          view = _this$props2.view,
          windowId = _this$props2.windowId,
          classes = _this$props2.classes,
          t = _this$props2.t,
          manifestError = _this$props2.manifestError;
    const _this$state = this.state,
          error = _this$state.error,
          hasError = _this$state.hasError;

    if (hasError) {
      return /*#__PURE__*/React.createElement(MinimalWindow, {
        windowId: windowId
      }, /*#__PURE__*/React.createElement(ErrorContent, {
        error: error,
        windowId: windowId
      }));
    }

    return /*#__PURE__*/React.createElement(Paper, {
      onFocus: focusWindow,
      component: "section",
      elevation: 1,
      id: windowId,
      className: cn(classes.window, ns('window'), maximized ? classes.maximized : null),
      "aria-label": t('window', {
        label
      })
    }, this.wrappedTopBar(), manifestError && /*#__PURE__*/React.createElement(ErrorContent, {
      error: {
        stack: manifestError
      },
      windowId: windowId
    }), /*#__PURE__*/React.createElement("div", {
      className: classes.middle
    }, /*#__PURE__*/React.createElement("div", {
      className: classes.middleLeft
    }, /*#__PURE__*/React.createElement("div", {
      className: classes.primaryWindow
    }, /*#__PURE__*/React.createElement(PrimaryWindow, {
      view: view,
      windowId: windowId,
      isFetching: isFetching,
      sideBarOpen: sideBarOpen
    })), /*#__PURE__*/React.createElement("div", {
      className: classes.companionAreaBottom
    }, /*#__PURE__*/React.createElement(CompanionArea, {
      windowId: windowId,
      position: "bottom"
    }))), /*#__PURE__*/React.createElement("div", {
      className: classes.companionAreaRight
    }, /*#__PURE__*/React.createElement(CompanionArea, {
      windowId: windowId,
      position: "right"
    }), /*#__PURE__*/React.createElement(CompanionArea, {
      windowId: windowId,
      position: "far-right"
    }))), /*#__PURE__*/React.createElement(CompanionArea, {
      windowId: windowId,
      position: "far-bottom"
    }), /*#__PURE__*/React.createElement(PluginHook, this.props));
  }

}
Window.contextType = MosaicWindowContext;
Window.defaultProps = {
  classes: {},
  focusWindow: () => {},
  isFetching: false,
  label: null,
  manifestError: null,
  maximized: false,
  sideBarOpen: false,
  view: undefined,
  windowDraggable: null,
  workspaceType: null
};