import React, { Component } from 'react';
import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';
import Tooltip from '@material-ui/core/Tooltip';
import Button from '@material-ui/core/Button';
import ItemListIcon from '@material-ui/icons/ReorderSharp';
import TocIcon from '@material-ui/icons/SortSharp';
import ThumbnailListIcon from '@material-ui/icons/ViewListSharp';
import Typography from '@material-ui/core/Typography';
import ArrowForwardIcon from '@material-ui/icons/ArrowForwardSharp';
import FormControl from '@material-ui/core/FormControl';
import Select from '@material-ui/core/Select';
import MenuItem from '@material-ui/core/MenuItem';
import CompanionWindow from '../containers/CompanionWindow';
import SidebarIndexList from '../containers/SidebarIndexList';
import SidebarIndexTableOfContents from '../containers/SidebarIndexTableOfContents';
/**
 * a panel showing the canvases for a given manifest
 */

export class WindowSideBarCanvasPanel extends Component {
  /** */
  constructor(props) {
    super(props);
    this.handleSequenceChange = this.handleSequenceChange.bind(this);
    this.handleVariantChange = this.handleVariantChange.bind(this);
    this.containerRef = /*#__PURE__*/React.createRef();
  }
  /** */


  static getUseableLabel(resource, index) {
    return resource && resource.getLabel && resource.getLabel().length > 0 ? resource.getLabel().getValue() : resource.id;
  }
  /** @private */


  handleSequenceChange(event) {
    const updateSequence = this.props.updateSequence;
    updateSequence(event.target.value);
  }
  /** @private */


  handleVariantChange(event, value) {
    const updateVariant = this.props.updateVariant;
    updateVariant(value);
  }
  /**
   * render
   */


  render() {
    const _this$props = this.props,
          classes = _this$props.classes,
          collection = _this$props.collection,
          id = _this$props.id,
          showMultipart = _this$props.showMultipart,
          sequenceId = _this$props.sequenceId,
          sequences = _this$props.sequences,
          t = _this$props.t,
          variant = _this$props.variant,
          showToc = _this$props.showToc,
          windowId = _this$props.windowId;
    let listComponent;

    if (variant === 'tableOfContents') {
      listComponent = /*#__PURE__*/React.createElement(SidebarIndexTableOfContents, {
        id: id,
        containerRef: this.containerRef,
        windowId: windowId
      });
    } else {
      listComponent = /*#__PURE__*/React.createElement(SidebarIndexList, {
        id: id,
        containerRef: this.containerRef,
        windowId: windowId
      });
    }

    return /*#__PURE__*/React.createElement(CompanionWindow, {
      title: t('canvasIndex'),
      id: id,
      windowId: windowId,
      ref: this.containerRef,
      otherRef: this.containerRef,
      titleControls: /*#__PURE__*/React.createElement(React.Fragment, null, sequences && sequences.length > 1 && /*#__PURE__*/React.createElement(FormControl, null, /*#__PURE__*/React.createElement(Select, {
        MenuProps: {
          anchorOrigin: {
            horizontal: 'left',
            vertical: 'bottom'
          },
          getContentAnchorEl: null
        },
        displayEmpty: true,
        value: sequenceId,
        onChange: this.handleSequenceChange,
        name: "sequenceId",
        classes: {
          select: classes.select
        },
        className: classes.selectEmpty
      }, sequences.map((s, i) => /*#__PURE__*/React.createElement(MenuItem, {
        value: s.id,
        key: s.id
      }, /*#__PURE__*/React.createElement(Typography, {
        variant: "body2"
      }, WindowSideBarCanvasPanel.getUseableLabel(s, i)))))), /*#__PURE__*/React.createElement("div", {
        className: classes.break
      }), /*#__PURE__*/React.createElement(Tabs, {
        value: variant,
        onChange: this.handleVariantChange,
        variant: "fullWidth",
        indicatorColor: "primary",
        textColor: "primary"
      }, showToc && /*#__PURE__*/React.createElement(Tooltip, {
        title: t('tableOfContentsList'),
        value: "tableOfContents"
      }, /*#__PURE__*/React.createElement(Tab, {
        className: classes.variantTab,
        value: "tableOfContents",
        "aria-label": t('tableOfContentsList'),
        "aria-controls": `tab-panel-${id}`,
        icon: /*#__PURE__*/React.createElement(TocIcon, {
          style: {
            transform: 'scale(-1, 1)'
          }
        })
      })), /*#__PURE__*/React.createElement(Tooltip, {
        title: t('itemList'),
        value: "item"
      }, /*#__PURE__*/React.createElement(Tab, {
        className: classes.variantTab,
        value: "item",
        "aria-label": t('itemList'),
        "aria-controls": `tab-panel-${id}`,
        icon: /*#__PURE__*/React.createElement(ItemListIcon, null)
      })), /*#__PURE__*/React.createElement(Tooltip, {
        title: t('thumbnailList'),
        value: "thumbnail"
      }, /*#__PURE__*/React.createElement(Tab, {
        className: classes.variantTab,
        value: "thumbnail",
        "aria-label": t('thumbnailList'),
        "aria-controls": `tab-panel-${id}`,
        icon: /*#__PURE__*/React.createElement(ThumbnailListIcon, null)
      }))))
    }, /*#__PURE__*/React.createElement("div", {
      id: `tab-panel-${id}`
    }, collection && /*#__PURE__*/React.createElement(Button, {
      fullWidth: true,
      onClick: showMultipart,
      endIcon: /*#__PURE__*/React.createElement(ArrowForwardIcon, null)
    }, /*#__PURE__*/React.createElement(Typography, {
      className: classes.collectionNavigationButton
    }, WindowSideBarCanvasPanel.getUseableLabel(collection))), listComponent));
  }

}
WindowSideBarCanvasPanel.defaultProps = {
  collection: null,
  sequenceId: null,
  sequences: [],
  showToc: false
};