import React from 'react';
import classNames from 'classnames';
import Grid from '@material-ui/core/Grid';
import Typography from '@material-ui/core/Typography';
import Window from '../containers/Window';
import WorkspaceMosaic from '../containers/WorkspaceMosaic';
import WorkspaceElastic from '../containers/WorkspaceElastic';
import ns from '../config/css-ns';
import { IIIFDropTarget } from './IIIFDropTarget';
/**
 * Represents a work area that contains any number of windows
 * @memberof Workspace
 * @private
 */

export class Workspace extends React.Component {
  /** */
  constructor(props) {
    super(props);
    this.handleDrop = this.handleDrop.bind(this);
  }
  /** */


  handleDrop({
    canvasId,
    manifestId,
    manifestJson
  }, props, monitor) {
    const _this$props = this.props,
          addWindow = _this$props.addWindow,
          allowNewWindows = _this$props.allowNewWindows;
    if (!allowNewWindows) return;
    addWindow({
      canvasId,
      manifest: manifestJson,
      manifestId
    });
  }
  /**
   * Determine which workspace to render by configured type
   */


  workspaceByType() {
    const _this$props2 = this.props,
          workspaceId = _this$props2.workspaceId,
          workspaceType = _this$props2.workspaceType,
          windowIds = _this$props2.windowIds;

    if (this.maximizedWindows()) {
      return this.maximizedWindows();
    }

    if (windowIds.length === 0) return this.zeroWindows();

    switch (workspaceType) {
      case 'elastic':
        return /*#__PURE__*/React.createElement(WorkspaceElastic, null);

      case 'mosaic':
        return /*#__PURE__*/React.createElement(WorkspaceMosaic, null);

      default:
        return windowIds.map(windowId => /*#__PURE__*/React.createElement(Window, {
          key: `${windowId}-${workspaceId}`,
          windowId: windowId
        }));
    }
  }
  /** */


  zeroWindows() {
    const t = this.props.t;
    return /*#__PURE__*/React.createElement(Grid, {
      alignItems: "center",
      container: true,
      style: {
        height: '100%'
      }
    }, /*#__PURE__*/React.createElement(Grid, {
      xs: 12,
      item: true
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "h1",
      component: "div",
      align: "center"
    }, t('welcome'))));
  }
  /**
   * Determine whether or not there are maximized windows
   */


  maximizedWindows() {
    const _this$props3 = this.props,
          maximizedWindowIds = _this$props3.maximizedWindowIds,
          workspaceId = _this$props3.workspaceId;

    if (maximizedWindowIds.length > 0) {
      return maximizedWindowIds.map(windowId => /*#__PURE__*/React.createElement(Window, {
        key: `${windowId}-${workspaceId}`,
        windowId: windowId,
        className: classNames(ns('workspace-maximized-window'))
      }));
    }

    return false;
  }
  /**
   * render
   */


  render() {
    const _this$props4 = this.props,
          classes = _this$props4.classes,
          isWorkspaceControlPanelVisible = _this$props4.isWorkspaceControlPanelVisible,
          t = _this$props4.t;
    return /*#__PURE__*/React.createElement(IIIFDropTarget, {
      onDrop: this.handleDrop
    }, /*#__PURE__*/React.createElement("div", {
      className: classNames(ns('workspace-viewport'), isWorkspaceControlPanelVisible && ns('workspace-with-control-panel'), isWorkspaceControlPanelVisible && classes.workspaceWithControlPanel, classes.workspaceViewport)
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "srOnly",
      component: "h1"
    }, t('miradorViewer')), this.workspaceByType()));
  }

}
Workspace.defaultProps = {
  addWindow: () => {},
  allowNewWindows: true,
  maximizedWindowIds: [],
  windowIds: []
};