import React from 'react';
import classNames from 'classnames';
import AddIcon from '@material-ui/icons/AddSharp';
import ExpandMoreIcon from '@material-ui/icons/ExpandMoreSharp';
import AppBar from '@material-ui/core/AppBar';
import Drawer from '@material-ui/core/Drawer';
import Grid from '@material-ui/core/Grid';
import Fab from '@material-ui/core/Fab';
import List from '@material-ui/core/List';
import Paper from '@material-ui/core/Paper';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import ns from '../config/css-ns';
import ManifestForm from '../containers/ManifestForm';
import ManifestListItem from '../containers/ManifestListItem';
import MiradorMenuButton from '../containers/MiradorMenuButton';
import { IIIFDropTarget } from './IIIFDropTarget';
import { PluginHook } from './PluginHook';
/**
 * An area for managing manifests and adding them to workspace
 * @memberof Workspace
 * @private
 */

export class WorkspaceAdd extends React.Component {
  /** */
  constructor(props) {
    super(props);
    this.state = {
      addResourcesOpen: false
    };
    this.ref = /*#__PURE__*/React.createRef();
    this.onSubmit = this.onSubmit.bind(this);
    this.setAddResourcesVisibility = this.setAddResourcesVisibility.bind(this);
    this.handleDrop = this.handleDrop.bind(this);
  }
  /** */


  handleDrop({
    manifestId,
    manifestJson
  }, props, monitor) {
    const addResource = this.props.addResource;

    if (manifestJson) {
      addResource(manifestId, manifestJson, {
        provider: 'file'
      });
    } else {
      addResource(manifestId);
    }

    this.scrollToTop();
  }
  /** @private */


  onSubmit() {
    this.setAddResourcesVisibility(false);
    this.scrollToTop();
  }
  /**
   * @private
   */


  setAddResourcesVisibility(bool) {
    this.setState({
      addResourcesOpen: bool
    });
  }
  /** Scroll the list back to the top */


  scrollToTop() {
    if (this.ref.current) {
      const el = this.ref.current;
      el.scrollTo({
        behavior: 'smooth',
        left: 0,
        top: 0
      });
    }
  }
  /**
   * render
   */


  render() {
    const _this$props = this.props,
          catalog = _this$props.catalog,
          setWorkspaceAddVisibility = _this$props.setWorkspaceAddVisibility,
          t = _this$props.t,
          classes = _this$props.classes;
    const addResourcesOpen = this.state.addResourcesOpen;
    const manifestList = catalog.map((resource, index) => /*#__PURE__*/React.createElement(ManifestListItem, Object.assign({}, index === 0 && {
      buttonRef: ref => ref && ref.focus()
    }, {
      key: resource.manifestId,
      manifestId: resource.manifestId,
      provider: resource.provider,
      handleClose: () => setWorkspaceAddVisibility(false)
    })));
    return /*#__PURE__*/React.createElement(IIIFDropTarget, {
      onDrop: this.handleDrop
    }, /*#__PURE__*/React.createElement("div", {
      ref: this.ref,
      className: classNames(ns('workspace-add'), classes.workspaceAdd)
    }, catalog.length < 1 ? /*#__PURE__*/React.createElement(Grid, {
      alignItems: "center",
      container: true,
      style: {
        height: '100%'
      }
    }, /*#__PURE__*/React.createElement(Grid, {
      xs: 12,
      item: true
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "h1",
      component: "div",
      align: "center"
    }, t('emptyResourceList')))) : /*#__PURE__*/React.createElement(Paper, {
      className: classes.list
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "srOnly",
      component: "h1"
    }, t('miradorResources')), /*#__PURE__*/React.createElement(PluginHook, this.props), /*#__PURE__*/React.createElement(List, {
      disablePadding: true
    }, manifestList)), /*#__PURE__*/React.createElement(Fab, {
      variant: "extended",
      disabled: addResourcesOpen,
      className: classNames(classes.fab, ns('add-resource-button')),
      color: "primary",
      onClick: () => this.setAddResourcesVisibility(true)
    }, /*#__PURE__*/React.createElement(AddIcon, null), t('addResource')), /*#__PURE__*/React.createElement(Drawer, {
      className: classNames({
        [classes.displayNone]: !addResourcesOpen
      }),
      classes: {
        paper: classes.paper
      },
      variant: "persistent",
      anchor: "bottom",
      open: addResourcesOpen,
      ModalProps: {
        disablePortal: true,
        hideBackdrop: true,
        style: {
          position: 'absolute'
        }
      }
    }, /*#__PURE__*/React.createElement(Paper, {
      className: classes.form
    }, /*#__PURE__*/React.createElement(AppBar, {
      position: "absolute",
      color: "primary",
      onClick: () => this.setAddResourcesVisibility(false)
    }, /*#__PURE__*/React.createElement(Toolbar, {
      variant: "dense"
    }, /*#__PURE__*/React.createElement(MiradorMenuButton, {
      "aria-label": t('closeAddResourceForm'),
      className: classes.menuButton,
      color: "inherit"
    }, /*#__PURE__*/React.createElement(ExpandMoreIcon, null)), /*#__PURE__*/React.createElement(Typography, {
      variant: "h2",
      noWrap: true,
      color: "inherit",
      className: classes.typographyBody
    }, t('addResource')))), /*#__PURE__*/React.createElement(ManifestForm, {
      addResourcesOpen: addResourcesOpen,
      onSubmit: this.onSubmit,
      onCancel: () => this.setAddResourcesVisibility(false)
    })))));
  }

}
WorkspaceAdd.defaultProps = {
  addResource: () => {},
  catalog: [],
  classes: {},
  t: key => key
};