import React from 'react';
import { Rnd } from 'react-rnd';
import ResizeObserver from 'react-resize-observer';
import classNames from 'classnames';
import WorkspaceElasticWindow from '../containers/WorkspaceElasticWindow';
import ns from '../config/css-ns';
/**
 * Represents a work area that contains any number of windows
 * @memberof Workspace
 * @private
 */

class WorkspaceElastic extends React.Component {
  /**
   */
  render() {
    const _this$props = this.props,
          classes = _this$props.classes,
          workspace = _this$props.workspace,
          elasticLayout = _this$props.elasticLayout,
          setWorkspaceViewportDimensions = _this$props.setWorkspaceViewportDimensions,
          setWorkspaceViewportPosition = _this$props.setWorkspaceViewportPosition;
    const viewportPosition = workspace.viewportPosition;
    const offsetX = workspace.width / 2;
    const offsetY = workspace.height / 2;
    return /*#__PURE__*/React.createElement("div", {
      style: {
        height: '100%',
        position: 'relative',
        width: '100%'
      }
    }, /*#__PURE__*/React.createElement(ResizeObserver, {
      onResize: rect => {
        setWorkspaceViewportDimensions(rect);
      }
    }), /*#__PURE__*/React.createElement(Rnd, {
      size: {
        height: workspace.height,
        width: workspace.width
      },
      position: {
        x: -1 * viewportPosition.x - offsetX,
        y: -1 * viewportPosition.y - offsetY
      },
      enableResizing: {
        bottom: false,
        bottomLeft: false,
        bottomRight: false,
        left: false,
        right: false,
        top: false,
        topLeft: false,
        topRight: false
      },
      onDragStop: (e, d) => {
        setWorkspaceViewportPosition({
          x: -1 * d.x - offsetX,
          y: -1 * d.y - offsetY
        });
      },
      cancel: `.${ns('window')}`,
      className: classNames(classes.workspace, ns('workspace')),
      disableDragging: !workspace.draggingEnabled
    }, Object.keys(elasticLayout).map(windowId => /*#__PURE__*/React.createElement(WorkspaceElasticWindow, {
      key: windowId,
      windowId: windowId
    }))));
  }

}

export default WorkspaceElastic;