import React, { Component } from 'react';
import Menu from '@material-ui/core/Menu';
import MenuItem from '@material-ui/core/MenuItem';
import Typography from '@material-ui/core/Typography';
import LanguageSettings from '../containers/LanguageSettings';
import { NestedMenu } from './NestedMenu';
import WorkspaceSelectionDialog from '../containers/WorkspaceSelectionDialog';
import ns from '../config/css-ns';
import ChangeThemeDialog from '../containers/ChangeThemeDialog';
import { PluginHook } from './PluginHook';
/**
 */

export class WorkspaceMenu extends Component {
  /**
   * constructor -
   */
  constructor(props) {
    super(props);
    this.state = {
      changeTheme: {},
      toggleZoom: {},
      workspaceSelection: {}
    };
    this.handleMenuItemClick = this.handleMenuItemClick.bind(this);
    this.handleMenuItemClose = this.handleMenuItemClose.bind(this);
  }
  /**
   * @private
   */


  handleMenuItemClick(item, event) {
    const obj = {};
    obj[item] = {};
    obj[item].open = true;
    obj[item].anchorEl = event.currentTarget;
    this.setState(obj);
  }
  /**
   * @private
   */


  handleMenuItemClose(item) {
    return event => {
      const obj = {};
      obj[item] = {};
      obj[item].open = false;
      obj[item].anchorEl = null;
      this.setState(obj);
    };
  }
  /**
   * @private
   */


  handleZoomToggleClick() {
    const _this$props = this.props,
          toggleZoomControls = _this$props.toggleZoomControls,
          showZoomControls = _this$props.showZoomControls;
    toggleZoomControls(!showZoomControls);
  }
  /**
   * render
   * @return
   */


  render() {
    const _this$props2 = this.props,
          containerId = _this$props2.containerId,
          handleClose = _this$props2.handleClose,
          anchorEl = _this$props2.anchorEl,
          showThemePicker = _this$props2.showThemePicker,
          isWorkspaceAddVisible = _this$props2.isWorkspaceAddVisible,
          t = _this$props2.t,
          showZoomControls = _this$props2.showZoomControls;
    const _this$state = this.state,
          changeTheme = _this$state.changeTheme,
          toggleZoom = _this$state.toggleZoom,
          workspaceSelection = _this$state.workspaceSelection;
    const container = document.querySelector(`#${containerId} .${ns('viewer')}`);
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Menu, {
      id: "workspace-menu",
      container: container,
      anchorEl: anchorEl,
      anchorOrigin: {
        horizontal: 'right',
        vertical: 'top'
      },
      transformOrigin: {
        horizontal: 'left',
        vertical: 'top'
      },
      open: Boolean(anchorEl),
      onClose: handleClose
    }, /*#__PURE__*/React.createElement(MenuItem, {
      "aria-haspopup": "true",
      disabled: isWorkspaceAddVisible,
      onClick: e => {
        this.handleZoomToggleClick(e);
        handleClose(e);
      },
      "aria-owns": toggleZoom.anchorEl ? 'toggle-zoom-menu' : undefined
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "body1"
    }, showZoomControls ? t('hideZoomControls') : t('showZoomControls'))), /*#__PURE__*/React.createElement(MenuItem, {
      "aria-haspopup": "true",
      onClick: e => {
        this.handleMenuItemClick('workspaceSelection', e);
        handleClose(e);
      },
      "aria-owns": workspaceSelection.anchorEl ? 'workspace-selection' : undefined
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "body1"
    }, t('selectWorkspaceMenu'))), /*#__PURE__*/React.createElement(NestedMenu, {
      label: t('language')
    }, /*#__PURE__*/React.createElement(LanguageSettings, {
      afterSelect: handleClose
    })), showThemePicker && /*#__PURE__*/React.createElement(MenuItem, {
      "aria-haspopup": "true",
      onClick: e => {
        this.handleMenuItemClick('changeTheme', e);
        handleClose(e);
      },
      "aria-owns": changeTheme.anchorEl ? 'change-theme' : undefined
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "body1"
    }, t('changeTheme'))), /*#__PURE__*/React.createElement(PluginHook, this.props)), Boolean(changeTheme.open) && /*#__PURE__*/React.createElement(ChangeThemeDialog, {
      container: container,
      handleClose: this.handleMenuItemClose('changeTheme'),
      open: Boolean(changeTheme.open)
    }), Boolean(workspaceSelection.open) && /*#__PURE__*/React.createElement(WorkspaceSelectionDialog, {
      open: Boolean(workspaceSelection.open),
      container: container,
      handleClose: this.handleMenuItemClose('workspaceSelection')
    }));
  }

}
WorkspaceMenu.defaultProps = {
  anchorEl: null,
  isWorkspaceAddVisible: false,
  showThemePicker: false,
  showZoomControls: false,
  t: key => key,
  toggleZoomControls: () => {}
};