function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import deepmerge from 'deepmerge';
import { validatePlugin } from './pluginValidation';
/** */

export function filterValidPlugins(plugins) {
  const _splitPluginsByValida = splitPluginsByValidation(plugins),
        validPlugins = _splitPluginsByValida.validPlugins,
        invalidPlugins = _splitPluginsByValida.invalidPlugins;

  logInvalidPlugins(invalidPlugins);
  return validPlugins;
}
/** */

function splitPluginsByValidation(plugins) {
  const invalidPlugins = [];
  const validPlugins = [];
  plugins.forEach(plugin => {
    if (Array.isArray(plugin)) {
      const allValid = plugin.every(p => validatePlugin(p));
      allValid ? validPlugins.push(...plugin) : invalidPlugins.push(...plugin);
    } else {
      validatePlugin(plugin) ? validPlugins.push(plugin) : invalidPlugins.push(plugin);
    }
  });
  return {
    invalidPlugins,
    validPlugins
  };
}
/** */


function logInvalidPlugins(plugins) {
  plugins.forEach(plugin => console.log(`Mirador: Plugin ${plugin.name} is not valid and was rejected.`));
}
/**  */


export function getReducersFromPlugins(plugins) {
  return plugins && plugins.reduce((acc, plugin) => _objectSpread(_objectSpread({}, acc), plugin.reducers), {});
}
/**  */

export function getConfigFromPlugins(plugins) {
  return plugins && plugins.reduce((acc, plugin) => deepmerge(acc, plugin.config || {}), {});
}
/**  */

export function getSagasFromPlugins(plugins) {
  return plugins && plugins.filter(plugin => plugin.saga).map(plugin => plugin.saga);
}