function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { createSelector } from 'reselect';
import union from 'lodash/union';
import without from 'lodash/without';
import { Utils } from 'manifesto.js/dist-esmodule/Utils';
import { getVisibleCanvasIds } from './canvases';
import { getCompanionWindow } from './companionWindows';
import { getSequenceTreeStructure } from './sequences';
/** */

function rangeContainsCanvasId(range, canvasId) {
  const canvasIds = range.getCanvasIds();

  for (let i = 0; i < canvasIds.length; i += 1) {
    if (Utils.normalisedUrlsMatch(canvasIds[i], canvasId)) {
      return true;
    }
  }

  return false;
}
/** */


function getAllParentIds(node) {
  if (node.parentNode === undefined) {
    return [];
  }

  if (node.parentNode.parentNode === undefined) {
    return [node.parentNode.id];
  }

  return [...getAllParentIds(node.parentNode), node.parentNode.id];
}
/** */


function getVisibleNodeIdsInSubTree(nodes, canvasIds) {
  return nodes.reduce((nodeIdAcc, node) => {
    const result = [];
    result.push(...nodeIdAcc);
    const nodeContainsVisibleCanvas = canvasIds.reduce((acc, canvasId) => acc || rangeContainsCanvasId(node.data, canvasId), false);
    const subTreeVisibleNodeIds = node.nodes.length > 0 ? getVisibleNodeIdsInSubTree(node.nodes, canvasIds) : [];
    result.push(...subTreeVisibleNodeIds);

    if (nodeContainsVisibleCanvas || subTreeVisibleNodeIds.length > 0) {
      result.push({
        containsVisibleCanvas: nodeContainsVisibleCanvas,
        descendantsContainVisibleCanvas: subTreeVisibleNodeIds.length > 0,
        id: node.id,
        leaf: node.nodes.length === 0,
        parentIds: getAllParentIds(node)
      });
    }

    return result;
  }, []);
}
/** */


const getVisibleLeafAndBranchNodeIds = createSelector([getSequenceTreeStructure, getVisibleCanvasIds], (tree, canvasIds) => {
  if (canvasIds.length === 0 || !tree) return [];
  return getVisibleNodeIdsInSubTree(tree.nodes, canvasIds);
});
/** */

export const getVisibleNodeIds = createSelector([getVisibleLeafAndBranchNodeIds], visibleLeafAndBranchNodeIds => visibleLeafAndBranchNodeIds.map(item => item.id));
const getVisibleBranchNodeIds = createSelector([getVisibleLeafAndBranchNodeIds], visibleLeafAndBranchNodeIds => visibleLeafAndBranchNodeIds.reduce((acc, item) => item.leaf || !item.descendantsContainVisibleCanvas ? acc : [...acc, item.id], []));
const getCanvasContainingNodeIds = createSelector([getVisibleLeafAndBranchNodeIds], visibleLeafAndBranchNodeIds => visibleLeafAndBranchNodeIds.reduce((acc, item) => item.containsVisibleCanvas ? [...acc, item] : acc, []));
/** */

export function getManuallyExpandedNodeIds(state, {
  companionWindowId
}, expanded) {
  const companionWindow = getCompanionWindow(state, {
    companionWindowId
  });
  return companionWindow.tocNodes ? Object.keys(companionWindow.tocNodes).reduce((acc, nodeId) => companionWindow.tocNodes[nodeId].expanded === expanded ? [...acc, nodeId] : acc, []) : [];
}
/** */

export function getExpandedNodeIds(state, {
  companionWindowId,
  windowId
}) {
  const visibleBranchNodeIds = getVisibleBranchNodeIds(state, {
    companionWindowId,
    windowId
  });
  const manuallyExpandedNodeIds = getManuallyExpandedNodeIds(state, {
    companionWindowId
  }, true);
  const manuallyClosedNodeIds = getManuallyExpandedNodeIds(state, {
    companionWindowId
  }, false);
  return without(union(manuallyExpandedNodeIds, visibleBranchNodeIds), ...manuallyClosedNodeIds);
}
/** */

export function getNodeIdToScrollTo(state, _ref) {
  let args = _extends({}, _ref);

  const canvasContainingNodeIds = getCanvasContainingNodeIds(state, _objectSpread({}, args));
  const collapsedNodeIds = getManuallyExpandedNodeIds(state, args, false);

  if (canvasContainingNodeIds && canvasContainingNodeIds.length > 0) {
    for (let i = 0; i < canvasContainingNodeIds[0].parentIds.length; i += 1) {
      if (collapsedNodeIds.indexOf(canvasContainingNodeIds[0].parentIds[i]) !== -1) {
        return canvasContainingNodeIds[0].parentIds[i];
      }
    }

    return canvasContainingNodeIds[0].id;
  }

  return null;
}
/**
 * Returns the default sidebar variant depending on whether or not ranges exist
 */

export const getDefaultSidebarVariant = createSelector([getSequenceTreeStructure], tree => tree && tree.nodes && tree.nodes.length > 0 ? 'tableOfContents' : 'item');