import React, { Component } from 'react';
import { Dialog, DialogTitle, ListItemIcon, ListItemText, MenuList, MenuItem, Typography, DialogContent } from '@material-ui/core';
import PaletteIcon from '@material-ui/icons/PaletteSharp';

/**
 * a simple dialog providing the possibility to switch the theme
 */
export class ChangeThemeDialog extends Component {
  /**
   * Set the initial focus when the dialog enters
   * Find the selected item by using the current theme
   * in a selector on the value attribute (which we need to set)
  */
  static setInitialFocus(dialogElement, selectedTheme) {
    const selectedListItem = dialogElement.querySelectorAll(`li[value="${selectedTheme}"]`);
    if (!selectedListItem || selectedListItem.length === 0) return;
    selectedListItem[0].focus();
  }
  /**
  */


  constructor(props) {
    super(props);
    this.selectedItemRef = /*#__PURE__*/React.createRef();
    this.handleThemeChange = this.handleThemeChange.bind(this);
  }
  /**
   * Propagate theme palette type selection into the global state
   */


  handleThemeChange(theme) {
    const _this$props = this.props,
          setSelectedTheme = _this$props.setSelectedTheme,
          handleClose = _this$props.handleClose;
    setSelectedTheme(theme);
    handleClose();
  }
  /** */


  render() {
    const _this$props2 = this.props,
          classes = _this$props2.classes,
          handleClose = _this$props2.handleClose,
          open = _this$props2.open,
          selectedTheme = _this$props2.selectedTheme,
          t = _this$props2.t,
          themeIds = _this$props2.themeIds;
    return /*#__PURE__*/React.createElement(Dialog, {
      onClose: handleClose,
      onEntered: dialog => ChangeThemeDialog.setInitialFocus(dialog, selectedTheme),
      open: open
    }, /*#__PURE__*/React.createElement(DialogTitle, {
      id: "change-the-dialog-title",
      disableTypography: true
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "h2"
    }, t('changeTheme'))), /*#__PURE__*/React.createElement(DialogContent, {
      className: classes.dialogContent
    }, /*#__PURE__*/React.createElement(MenuList, null, themeIds.map(value => /*#__PURE__*/React.createElement(MenuItem, {
      key: value,
      className: classes.listitem,
      onClick: () => {
        this.handleThemeChange(value);
      },
      selected: value === selectedTheme,
      value: value
    }, /*#__PURE__*/React.createElement(ListItemIcon, null, /*#__PURE__*/React.createElement(PaletteIcon, {
      className: classes[value]
    })), /*#__PURE__*/React.createElement(ListItemText, null, t(value)))))));
  }

}
ChangeThemeDialog.defaultProps = {
  open: false,
  themeIds: []
};