import React, { Component } from 'react';
import { Button, Chip, Dialog, DialogActions, DialogTitle, Link, MenuList, MenuItem, Typography } from '@material-ui/core';
import ArrowBackIcon from '@material-ui/icons/ArrowBackSharp';
import Skeleton from '@material-ui/lab/Skeleton';
import { LabelValueMetadata } from './LabelValueMetadata';
import CollapsibleSection from '../containers/CollapsibleSection';
import ScrollIndicatedDialogContent from '../containers/ScrollIndicatedDialogContent';
import ManifestInfo from '../containers/ManifestInfo';
/**
 */

function asArray(value) {
  if (!Array.isArray(value)) {
    return [value];
  }

  return value;
}
/**
 * a dialog providing the possibility to select the collection
 */


export class CollectionDialog extends Component {
  /** */
  static getUseableLabel(resource, index) {
    return resource && resource.getLabel && resource.getLabel().length > 0 ? resource.getLabel().getValue() : String(index + 1);
  }
  /** */


  constructor(props) {
    super(props);
    this.state = {
      filter: null
    };
    this.hideDialog = this.hideDialog.bind(this);
  }
  /** */


  setFilter(filter) {
    this.setState({
      filter
    });
  }
  /** */


  hideDialog() {
    const _this$props = this.props,
          hideCollectionDialog = _this$props.hideCollectionDialog,
          windowId = _this$props.windowId;
    hideCollectionDialog(windowId);
  }
  /** */


  selectCollection(c) {
    const _this$props2 = this.props,
          collectionPath = _this$props2.collectionPath,
          manifestId = _this$props2.manifestId,
          showCollectionDialog = _this$props2.showCollectionDialog,
          windowId = _this$props2.windowId;
    showCollectionDialog(c.id, [...collectionPath, manifestId], windowId);
  }
  /** */


  goToPreviousCollection() {
    const _this$props3 = this.props,
          collectionPath = _this$props3.collectionPath,
          showCollectionDialog = _this$props3.showCollectionDialog,
          windowId = _this$props3.windowId;
    showCollectionDialog(collectionPath[collectionPath.length - 1], collectionPath.slice(0, -1), windowId);
  }
  /** */


  selectManifest(m) {
    const _this$props4 = this.props,
          addWindow = _this$props4.addWindow,
          collectionPath = _this$props4.collectionPath,
          manifestId = _this$props4.manifestId,
          setWorkspaceAddVisibility = _this$props4.setWorkspaceAddVisibility,
          updateWindow = _this$props4.updateWindow,
          windowId = _this$props4.windowId;

    if (windowId) {
      updateWindow(windowId, {
        canvasId: null,
        collectionPath: [...collectionPath, manifestId],
        manifestId: m.id
      });
    } else {
      addWindow({
        collectionPath: [...collectionPath, manifestId],
        manifestId: m.id
      });
    }

    this.hideDialog();
    setWorkspaceAddVisibility(false);
  }
  /** */


  dialogContainer() {
    const _this$props5 = this.props,
          containerId = _this$props5.containerId,
          windowId = _this$props5.windowId;
    return document.querySelector(`#${containerId} #${windowId}`);
  }
  /** */


  placeholder() {
    const classes = this.props.classes;
    return /*#__PURE__*/React.createElement(Dialog, {
      className: classes.dialog,
      onClose: this.hideDialog,
      open: true,
      container: this.dialogContainer(),
      BackdropProps: this.backdropProps()
    }, /*#__PURE__*/React.createElement(DialogTitle, {
      id: "select-collection",
      disableTypography: true
    }, /*#__PURE__*/React.createElement(Skeleton, {
      className: classes.placeholder,
      variant: "text"
    })), /*#__PURE__*/React.createElement(ScrollIndicatedDialogContent, null, /*#__PURE__*/React.createElement(Skeleton, {
      className: classes.placeholder,
      variant: "text"
    }), /*#__PURE__*/React.createElement(Skeleton, {
      className: classes.placeholder,
      variant: "text"
    })));
  }
  /** */


  backdropProps() {
    const classes = this.props.classes;
    return {
      classes: {
        root: classes.dialog
      }
    };
  }
  /** */


  render() {
    const _this$props6 = this.props,
          classes = _this$props6.classes,
          collection = _this$props6.collection,
          error = _this$props6.error,
          isMultipart = _this$props6.isMultipart,
          manifest = _this$props6.manifest,
          ready = _this$props6.ready,
          t = _this$props6.t;
    const filter = this.state.filter;
    if (error) return null; // If this component is optimistically rendering ahead of the window its in
    // force a re-render so that it is placed correctly. The right thing here is
    // to maybe pass a ref.

    if (!this.dialogContainer()) {
      this.forceUpdate();
      return /*#__PURE__*/React.createElement(React.Fragment, null);
    }

    if (!ready) return this.placeholder();
    const rights = manifest && asArray(manifest.getProperty('rights') || manifest.getProperty('license'));
    const requiredStatement = manifest && asArray(manifest.getRequiredStatement()).filter(l => l.getValue()).map(labelValuePair => ({
      label: null,
      values: labelValuePair.getValues()
    }));
    const collections = manifest.getCollections();
    const currentFilter = filter || (collections.length > 0 ? 'collections' : 'manifests');
    return /*#__PURE__*/React.createElement(Dialog, {
      className: classes.dialog,
      onClose: this.hideDialog,
      container: this.dialogContainer(),
      BackdropProps: this.backdropProps(),
      open: true
    }, /*#__PURE__*/React.createElement(DialogTitle, {
      id: "select-collection",
      disableTypography: true
    }, /*#__PURE__*/React.createElement(Typography, {
      component: "div",
      variant: "overline"
    }, t(isMultipart ? 'multipartCollection' : 'collection')), /*#__PURE__*/React.createElement(Typography, {
      variant: "h3"
    }, CollectionDialog.getUseableLabel(manifest))), /*#__PURE__*/React.createElement(ScrollIndicatedDialogContent, {
      className: classes.dialogContent
    }, collection && /*#__PURE__*/React.createElement(Button, {
      startIcon: /*#__PURE__*/React.createElement(ArrowBackIcon, null),
      onClick: () => this.goToPreviousCollection()
    }, CollectionDialog.getUseableLabel(collection)), /*#__PURE__*/React.createElement("div", {
      className: classes.collectionMetadata
    }, /*#__PURE__*/React.createElement(ManifestInfo, {
      manifestId: manifest.id
    }), /*#__PURE__*/React.createElement(CollapsibleSection, {
      id: "select-collection-rights",
      label: t('attributionTitle')
    }, requiredStatement && /*#__PURE__*/React.createElement(LabelValueMetadata, {
      labelValuePairs: requiredStatement,
      defaultLabel: t('attribution')
    }), rights && rights.length > 0 && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Typography, {
      variant: "subtitle2",
      component: "dt"
    }, t('rights')), rights.map(v => /*#__PURE__*/React.createElement(Typography, {
      variant: "body1",
      component: "dd",
      key: v
    }, /*#__PURE__*/React.createElement(Link, {
      target: "_blank",
      rel: "noopener noreferrer",
      href: v
    }, v)))))), /*#__PURE__*/React.createElement("div", {
      className: classes.collectionFilter
    }, manifest.getTotalCollections() > 0 && /*#__PURE__*/React.createElement(Chip, {
      clickable: true,
      color: currentFilter === 'collections' ? 'primary' : 'default',
      onClick: () => this.setFilter('collections'),
      label: t('totalCollections', {
        count: manifest.getTotalCollections()
      })
    }), manifest.getTotalManifests() > 0 && /*#__PURE__*/React.createElement(Chip, {
      clickable: true,
      color: currentFilter === 'manifests' ? 'primary' : 'default',
      onClick: () => this.setFilter('manifests'),
      label: t('totalManifests', {
        count: manifest.getTotalManifests()
      })
    })), currentFilter === 'collections' && /*#__PURE__*/React.createElement(MenuList, null, collections.map(c => /*#__PURE__*/React.createElement(MenuItem, {
      key: c.id,
      onClick: () => {
        this.selectCollection(c);
      }
    }, CollectionDialog.getUseableLabel(c)))), currentFilter === 'manifests' && /*#__PURE__*/React.createElement(MenuList, null, manifest.getManifests().map(m => /*#__PURE__*/React.createElement(MenuItem, {
      key: m.id,
      onClick: () => {
        this.selectManifest(m);
      }
    }, CollectionDialog.getUseableLabel(m))))), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
      onClick: this.hideDialog
    }, t('close'))));
  }

}
CollectionDialog.defaultProps = {
  collection: null,
  collectionPath: [],
  containerId: null,
  error: null,
  isMultipart: false,
  ready: false,
  windowId: null
};