import React, { Component } from 'react';
import Avatar from '@material-ui/core/Avatar';
import Chip from '@material-ui/core/Chip';
import AnnotationIcon from '@material-ui/icons/CommentSharp';
import SearchIcon from '@material-ui/icons/SearchSharp';
import classNames from 'classnames';
import 'intersection-observer'; // polyfill needed for Safari

import IntersectionObserver from '@researchgate/react-intersection-observer';
import MiradorCanvas from '../lib/MiradorCanvas';
import IIIFThumbnail from '../containers/IIIFThumbnail';
/**
 * Represents a WindowViewer in the mirador workspace. Responsible for mounting
 * OSD and Navigation
 */

export class GalleryViewThumbnail extends Component {
  /** */
  constructor(props) {
    super(props);
    this.state = {
      requestedAnnotations: false
    };
    this.handleSelect = this.handleSelect.bind(this);
    this.handleKey = this.handleKey.bind(this);
    this.handleIntersection = this.handleIntersection.bind(this);
  }
  /** @private */


  handleSelect() {
    const _this$props = this.props,
          canvas = _this$props.canvas,
          selected = _this$props.selected,
          setCanvas = _this$props.setCanvas,
          focusOnCanvas = _this$props.focusOnCanvas;

    if (selected) {
      focusOnCanvas();
    } else {
      setCanvas(canvas.id);
    }
  }
  /** @private */


  handleKey(event) {
    const _this$props2 = this.props,
          canvas = _this$props2.canvas,
          setCanvas = _this$props2.setCanvas,
          focusOnCanvas = _this$props2.focusOnCanvas;
    this.keys = {
      enter: 'Enter',
      space: ' '
    };
    this.chars = {
      enter: 13,
      space: 32
    };
    const enterOrSpace = event.key === this.keys.enter || event.which === this.chars.enter || event.key === this.keys.space || event.which === this.chars.space;

    if (enterOrSpace) {
      focusOnCanvas();
    } else {
      setCanvas(canvas.id);
    }
  }
  /** */


  handleIntersection({
    isIntersecting
  }) {
    const _this$props3 = this.props,
          annotationsCount = _this$props3.annotationsCount,
          requestCanvasAnnotations = _this$props3.requestCanvasAnnotations;
    const requestedAnnotations = this.state.requestedAnnotations;
    if (!isIntersecting || annotationsCount === undefined || annotationsCount > 0 || requestedAnnotations) return;
    this.setState({
      requestedAnnotations: true
    });
    requestCanvasAnnotations();
  }
  /**
   * Renders things
   */


  render() {
    const _this$props4 = this.props,
          annotationsCount = _this$props4.annotationsCount,
          searchAnnotationsCount = _this$props4.searchAnnotationsCount,
          canvas = _this$props4.canvas,
          classes = _this$props4.classes,
          config = _this$props4.config,
          selected = _this$props4.selected;
    const miradorCanvas = new MiradorCanvas(canvas);
    return /*#__PURE__*/React.createElement(IntersectionObserver, {
      onChange: this.handleIntersection
    }, /*#__PURE__*/React.createElement("div", {
      key: canvas.index,
      className: classNames(classes.galleryViewItem, selected ? classes.selected : '', searchAnnotationsCount > 0 ? classes.hasAnnotations : ''),
      onClick: this.handleSelect,
      onKeyUp: this.handleKey,
      role: "button",
      tabIndex: 0
    }, /*#__PURE__*/React.createElement(IIIFThumbnail, {
      resource: canvas,
      labelled: true,
      variant: "outside",
      maxWidth: config.width,
      maxHeight: config.height,
      style: {
        margin: '0 auto',
        maxWidth: `${Math.ceil(config.height * miradorCanvas.aspectRatio)}px`
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: classes.chips
    }, searchAnnotationsCount > 0 && /*#__PURE__*/React.createElement(Chip, {
      avatar: /*#__PURE__*/React.createElement(Avatar, {
        className: classes.avatar,
        classes: {
          circle: classes.avatarIcon
        }
      }, /*#__PURE__*/React.createElement(SearchIcon, {
        fontSize: "small"
      })),
      label: searchAnnotationsCount,
      className: classNames(classes.searchChip),
      size: "small"
    }), (annotationsCount || 0) > 0 && /*#__PURE__*/React.createElement(Chip, {
      avatar: /*#__PURE__*/React.createElement(Avatar, {
        className: classes.avatar,
        classes: {
          circle: classes.avatarIcon
        }
      }, /*#__PURE__*/React.createElement(AnnotationIcon, {
        className: classes.annotationIcon
      })),
      label: annotationsCount,
      className: classNames(classes.annotationsChip),
      size: "small"
    })))));
  }

}
GalleryViewThumbnail.defaultProps = {
  annotationsCount: undefined,
  config: {
    height: 100,
    width: null
  },
  requestCanvasAnnotations: () => {},
  searchAnnotationsCount: 0,
  selected: false
};