import React, { Component } from 'react';
import { AccessTokenSender } from './AccessTokenSender';
import { NewWindow } from './NewWindow';
import WindowAuthenticationBar from '../containers/WindowAuthenticationBar';
/**
 * Opens a new window for click
 */

export class IIIFAuthentication extends Component {
  /** */
  constructor(props) {
    super(props);
    this.performLogout = this.performLogout.bind(this);
    this.onReceiveAccessTokenMessage = this.onReceiveAccessTokenMessage.bind(this);
  }
  /** */


  onReceiveAccessTokenMessage(payload) {
    const _this$props = this.props,
          authServiceId = _this$props.authServiceId,
          accessTokenServiceId = _this$props.accessTokenServiceId,
          resolveAccessTokenRequest = _this$props.resolveAccessTokenRequest;
    resolveAccessTokenRequest(authServiceId, accessTokenServiceId, payload);
  }
  /** */


  defaultAuthBarProps() {
    const _this$props2 = this.props,
          authServiceId = _this$props2.authServiceId,
          windowId = _this$props2.windowId,
          status = _this$props2.status,
          logoutServiceId = _this$props2.logoutServiceId;
    return {
      authServiceId,
      hasLogoutService: !!logoutServiceId,
      status,
      windowId
    };
  }
  /** handle the IIIF logout workflow */


  performLogout() {
    const _this$props3 = this.props,
          accessTokenServiceId = _this$props3.accessTokenServiceId,
          authServiceId = _this$props3.authServiceId,
          features = _this$props3.features,
          logoutServiceId = _this$props3.logoutServiceId,
          resetAuthenticationState = _this$props3.resetAuthenticationState,
          openWindow = _this$props3.openWindow;
    openWindow(logoutServiceId, undefined, features);
    resetAuthenticationState({
      authServiceId,
      tokenServiceId: accessTokenServiceId
    });
  }
  /** Render the auth bar for logged in users */


  renderLoggedIn() {
    const _this$props4 = this.props,
          isInteractive = _this$props4.isInteractive,
          logoutConfirm = _this$props4.logoutConfirm,
          t = _this$props4.t;
    if (!isInteractive) return null;
    return /*#__PURE__*/React.createElement(WindowAuthenticationBar, Object.assign({
      confirmButton: logoutConfirm || t('logout'),
      onConfirm: this.performLogout
    }, this.defaultAuthBarProps()));
  }
  /** Render whatever shows up after the interactive login attempt fails */


  renderFailure() {
    const _this$props5 = this.props,
          handleAuthInteraction = _this$props5.handleAuthInteraction,
          header = _this$props5.failureHeader,
          description = _this$props5.failureDescription,
          t = _this$props5.t,
          authServiceId = _this$props5.authServiceId,
          windowId = _this$props5.windowId;
    return /*#__PURE__*/React.createElement(WindowAuthenticationBar, Object.assign({
      header: header,
      description: description,
      confirmButton: t('retry'),
      onConfirm: () => handleAuthInteraction(windowId, authServiceId)
    }, this.defaultAuthBarProps()));
  }
  /** Render the login bar after we're logging in */


  renderLoggingInCookie() {
    const _this$props6 = this.props,
          accessTokenServiceId = _this$props6.accessTokenServiceId,
          authServiceId = _this$props6.authServiceId,
          resolveAuthenticationRequest = _this$props6.resolveAuthenticationRequest,
          features = _this$props6.features;
    return /*#__PURE__*/React.createElement(React.Fragment, null, this.renderLogin(), /*#__PURE__*/React.createElement(NewWindow, {
      name: "IiifLoginSender",
      url: `${authServiceId}?origin=${window.origin}`,
      features: features,
      onClose: () => resolveAuthenticationRequest(authServiceId, accessTokenServiceId)
    }));
  }
  /** Render the login bar after we're logging in */


  renderLoggingInToken() {
    const accessTokenServiceId = this.props.accessTokenServiceId;
    return /*#__PURE__*/React.createElement(React.Fragment, null, this.renderLogin(), /*#__PURE__*/React.createElement(AccessTokenSender, {
      handleAccessTokenMessage: this.onReceiveAccessTokenMessage,
      url: accessTokenServiceId
    }));
  }
  /** Render a login bar */


  renderLogin() {
    const _this$props7 = this.props,
          confirm = _this$props7.confirm,
          description = _this$props7.description,
          handleAuthInteraction = _this$props7.handleAuthInteraction,
          header = _this$props7.header,
          isInteractive = _this$props7.isInteractive,
          label = _this$props7.label,
          authServiceId = _this$props7.authServiceId,
          windowId = _this$props7.windowId;
    if (!isInteractive) return null;
    return /*#__PURE__*/React.createElement(WindowAuthenticationBar, Object.assign({
      header: header,
      description: description,
      label: label,
      confirmButton: confirm,
      onConfirm: () => handleAuthInteraction(windowId, authServiceId)
    }, this.defaultAuthBarProps()));
  }
  /** */


  render() {
    const _this$props8 = this.props,
          authServiceId = _this$props8.authServiceId,
          status = _this$props8.status;
    if (!authServiceId) return null;
    if (status === null) return this.renderLogin();
    if (status === 'cookie') return this.renderLoggingInCookie();
    if (status === 'token') return this.renderLoggingInToken();
    if (status === 'failed') return this.renderFailure();
    if (status === 'ok') return this.renderLoggedIn();
    return null;
  }

}
IIIFAuthentication.defaultProps = {
  confirm: undefined,
  description: undefined,
  failureDescription: undefined,
  failureHeader: undefined,
  features: 'centerscreen',
  header: undefined,
  isInteractive: true,
  label: undefined,
  logoutConfirm: undefined,
  logoutServiceId: undefined,
  openWindow: window.open,
  status: null,
  t: k => k
};