function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import 'intersection-observer'; // polyfill needed for Safari

import Typography from '@material-ui/core/Typography';
import IntersectionObserver from '@researchgate/react-intersection-observer';
import classNames from 'classnames';
import getThumbnail from '../lib/ThumbnailFactory';
/**
 * Uses InteractionObserver to "lazy" load canvas thumbnails that are in view.
 */

export class IIIFThumbnail extends Component {
  /** */
  static getUseableLabel(resource, index) {
    return resource && resource.getLabel && resource.getLabel().length > 0 ? resource.getLabel().getValue() : String(index + 1);
  }
  /**
   */


  constructor(props) {
    super(props);
    this.state = {
      loaded: false
    };
    this.handleIntersection = this.handleIntersection.bind(this);
  }
  /** */


  componentDidMount() {
    this.setState(state => _objectSpread(_objectSpread({}, state), {}, {
      image: this.image()
    }));
  }
  /** */


  componentDidUpdate(prevProps) {
    const _this$props = this.props,
          maxHeight = _this$props.maxHeight,
          maxWidth = _this$props.maxWidth,
          resource = _this$props.resource;

    if (prevProps.maxHeight !== maxHeight || prevProps.maxWidth !== maxWidth || prevProps.resource !== resource) {
      this.setState(state => _objectSpread(_objectSpread({}, state), {}, {
        image: this.image()
      })); // eslint-disable-line
    }
  }
  /**
   * Handles the intersection (visibility) of a given thumbnail, by requesting
   * the image and then updating the state.
   */


  handleIntersection(event) {
    const loaded = this.state.loaded;
    if (loaded || !event.isIntersecting) return;
    this.setState(state => _objectSpread(_objectSpread({}, state), {}, {
      loaded: true
    }));
  }
  /**
   *
  */


  imageStyles() {
    const _this$props2 = this.props,
          maxHeight = _this$props2.maxHeight,
          maxWidth = _this$props2.maxWidth,
          style = _this$props2.style;
    const image = this.image();
    const styleProps = {
      height: 'auto',
      width: 'auto'
    };
    if (!image) return _objectSpread(_objectSpread({}, style), {}, {
      height: maxHeight || 'auto',
      width: maxWidth || 'auto'
    });
    const thumbHeight = image.height,
          thumbWidth = image.width;

    if (thumbHeight && thumbWidth) {
      if (maxHeight && thumbHeight > maxHeight || maxWidth && thumbWidth > maxWidth) {
        const aspectRatio = thumbWidth / thumbHeight;

        if (maxHeight && maxWidth) {
          if (maxWidth / maxHeight < aspectRatio) {
            styleProps.height = Math.round(maxWidth / aspectRatio);
            styleProps.width = maxWidth;
          } else {
            styleProps.height = maxHeight;
            styleProps.width = Math.round(maxHeight * aspectRatio);
          }
        } else if (maxHeight) {
          styleProps.height = maxHeight;
          styleProps.maxWidth = Math.round(maxHeight * aspectRatio);
        } else if (maxWidth) {
          styleProps.width = maxWidth;
          styleProps.maxHeight = Math.round(maxWidth / aspectRatio);
        }
      } else {
        styleProps.width = thumbWidth;
        styleProps.height = thumbHeight;
      }
    } else if (thumbHeight && !thumbWidth) {
      styleProps.height = maxHeight;
    } else if (!thumbHeight && thumbWidth) {
      styleProps.width = maxWidth;
    } else {
      // The thumbnail wasn't retrieved via an Image API service,
      // and its dimensions are not specified in the JSON-LD
      // (note that this may result in a blurry image)
      styleProps.width = maxWidth;
      styleProps.height = maxHeight;
    }

    return _objectSpread(_objectSpread({}, styleProps), style);
  }
  /** */


  image() {
    const _this$props3 = this.props,
          thumbnail = _this$props3.thumbnail,
          resource = _this$props3.resource,
          maxHeight = _this$props3.maxHeight,
          maxWidth = _this$props3.maxWidth;
    if (thumbnail) return thumbnail;
    const image = getThumbnail(resource, {
      maxHeight,
      maxWidth
    });
    if (image && image.url) return image;
    return undefined;
  }
  /** */


  label() {
    const _this$props4 = this.props,
          label = _this$props4.label,
          resource = _this$props4.resource;
    return label || IIIFThumbnail.getUseableLabel(resource);
  }
  /**
   */


  render() {
    const _this$props5 = this.props,
          children = _this$props5.children,
          classes = _this$props5.classes,
          imagePlaceholder = _this$props5.imagePlaceholder,
          labelled = _this$props5.labelled,
          thumbnail = _this$props5.thumbnail,
          variant = _this$props5.variant;
    const _this$state = this.state,
          image = _this$state.image,
          loaded = _this$state.loaded;

    const _ref = loaded && (thumbnail || image) || {},
          _ref$url = _ref.url,
          src = _ref$url === void 0 ? imagePlaceholder : _ref$url;

    return /*#__PURE__*/React.createElement("div", {
      className: classNames(classes.root, {
        [classes[`${variant}Root`]]: variant
      })
    }, /*#__PURE__*/React.createElement(IntersectionObserver, {
      onChange: this.handleIntersection
    }, /*#__PURE__*/React.createElement("img", {
      alt: "",
      role: "presentation",
      src: src,
      style: this.imageStyles(),
      className: classes.image
    })), labelled && /*#__PURE__*/React.createElement("div", {
      className: classNames(classes.label, {
        [classes[`${variant}Label`]]: variant
      })
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "caption",
      classes: {
        root: classNames(classes.caption, {
          [classes[`${variant}Caption`]]: variant
        })
      }
    }, this.label())), children);
  }

}
IIIFThumbnail.defaultProps = {
  children: null,
  classes: {},
  // Transparent "gray"
  imagePlaceholder: 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVR42mMMDQmtBwADgwF/Op8FmAAAAABJRU5ErkJggg==',
  label: undefined,
  labelled: false,
  maxHeight: null,
  maxWidth: null,
  style: {},
  thumbnail: null,
  variant: null
};