import React from 'react';
import ListItem from '@material-ui/core/ListItem';
import ButtonBase from '@material-ui/core/ButtonBase';
import Grid from '@material-ui/core/Grid';
import Typography from '@material-ui/core/Typography';
import Skeleton from '@material-ui/lab/Skeleton';
import { Img } from 'react-image';
import ManifestListItemError from '../containers/ManifestListItemError';
import ns from '../config/css-ns';
/**
 * Represents an item in a list of currently-loaded or loading manifests
 * @param {object} props
 * @param {object} [props.manifest = string]
 */

/** */

export class ManifestListItem extends React.Component {
  /** */
  constructor(props) {
    super(props);
    this.handleOpenButtonClick = this.handleOpenButtonClick.bind(this);
  }
  /** */


  componentDidMount() {
    const _this$props = this.props,
          fetchManifest = _this$props.fetchManifest,
          manifestId = _this$props.manifestId,
          ready = _this$props.ready,
          isFetching = _this$props.isFetching,
          error = _this$props.error,
          provider = _this$props.provider;
    if (!ready && !error && !isFetching && provider !== 'file') fetchManifest(manifestId);
  }
  /**
   * Handling open button click
   */


  handleOpenButtonClick() {
    const _this$props2 = this.props,
          addWindow = _this$props2.addWindow,
          handleClose = _this$props2.handleClose,
          manifestId = _this$props2.manifestId;
    addWindow({
      manifestId
    });
    handleClose();
  }
  /** */


  render() {
    const _this$props3 = this.props,
          active = _this$props3.active,
          buttonRef = _this$props3.buttonRef,
          manifestId = _this$props3.manifestId,
          ready = _this$props3.ready,
          title = _this$props3.title,
          thumbnail = _this$props3.thumbnail,
          manifestLogo = _this$props3.manifestLogo,
          size = _this$props3.size,
          classes = _this$props3.classes,
          provider = _this$props3.provider,
          t = _this$props3.t,
          error = _this$props3.error,
          isCollection = _this$props3.isCollection,
          isMultipart = _this$props3.isMultipart;
    const placeholder = /*#__PURE__*/React.createElement(Grid, {
      container: true,
      className: ns('manifest-list-item'),
      spacing: 2
    }, /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 3,
      sm: 2
    }, /*#__PURE__*/React.createElement(Skeleton, {
      className: classes.placeholder,
      variant: "rect",
      height: 80,
      width: 120
    })), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 9,
      sm: 6
    }, /*#__PURE__*/React.createElement(Skeleton, {
      className: classes.placeholder,
      variant: "text"
    })), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 8,
      sm: 2
    }, /*#__PURE__*/React.createElement(Skeleton, {
      className: classes.placeholder,
      variant: "text"
    }), /*#__PURE__*/React.createElement(Skeleton, {
      className: classes.placeholder,
      variant: "text"
    })), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 4,
      sm: 2
    }, /*#__PURE__*/React.createElement(Skeleton, {
      className: classes.placeholder,
      variant: "rect",
      height: 60,
      width: 60
    })));

    if (error) {
      return /*#__PURE__*/React.createElement(ListItem, {
        divider: true,
        className: classes.root,
        "data-manifestid": manifestId
      }, /*#__PURE__*/React.createElement(ManifestListItemError, {
        manifestId: manifestId
      }));
    }

    return /*#__PURE__*/React.createElement(ListItem, {
      divider: true,
      className: [classes.root, active ? classes.active : ''].join(' '),
      "data-manifestid": manifestId
    }, ready ? /*#__PURE__*/React.createElement(Grid, {
      container: true,
      className: ns('manifest-list-item'),
      spacing: 2
    }, /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 12,
      sm: 6,
      className: classes.buttonGrid
    }, /*#__PURE__*/React.createElement(ButtonBase, {
      ref: buttonRef,
      className: ns('manifest-list-item-title'),
      style: {
        width: '100%'
      },
      onClick: this.handleOpenButtonClick
    }, /*#__PURE__*/React.createElement(Grid, {
      container: true,
      spacing: 2,
      className: classes.label,
      component: "span"
    }, /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 4,
      sm: 3,
      component: "span"
    }, /*#__PURE__*/React.createElement(Img, {
      className: [classes.thumbnail, ns('manifest-list-item-thumb')].join(' '),
      src: [thumbnail],
      alt: "",
      height: "80",
      unloader: /*#__PURE__*/React.createElement(Skeleton, {
        variant: "rect",
        animation: false,
        className: classes.placeholder,
        height: 80,
        width: 120
      })
    })), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 8,
      sm: 9,
      component: "span"
    }, isCollection && /*#__PURE__*/React.createElement(Typography, {
      component: "div",
      variant: "overline"
    }, t(isMultipart ? 'multipartCollection' : 'collection')), /*#__PURE__*/React.createElement(Typography, {
      component: "span",
      variant: "h6"
    }, title || manifestId))))), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 8,
      sm: 4
    }, /*#__PURE__*/React.createElement(Typography, {
      className: ns('manifest-list-item-provider')
    }, provider || t('addedFromUrl')), /*#__PURE__*/React.createElement(Typography, null, t('numItems', {
      number: size
    }))), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 4,
      sm: 2
    }, /*#__PURE__*/React.createElement(Img, {
      src: [manifestLogo],
      alt: "",
      role: "presentation",
      className: classes.logo,
      unloader: /*#__PURE__*/React.createElement(Skeleton, {
        variant: "rect",
        animation: false,
        className: classes.placeholder,
        height: 60,
        width: 60
      })
    }))) : placeholder);
  }

}
ManifestListItem.defaultProps = {
  active: false,
  buttonRef: undefined,
  classes: {},
  error: null,
  handleClose: () => {},
  isCollection: false,
  isFetching: false,
  isMultipart: false,
  manifestLogo: null,
  provider: null,
  ready: false,
  size: 0,
  t: key => key,
  thumbnail: null,
  title: null
};