import React, { Component, lazy, Suspense } from 'react';
import classNames from 'classnames';
import WindowSideBar from '../containers/WindowSideBar';
import CompanionArea from '../containers/CompanionArea';
import CollectionDialog from '../containers/CollectionDialog';
import ns from '../config/css-ns';
const AudioViewer = /*#__PURE__*/lazy(() => import('../containers/AudioViewer'));
const GalleryView = /*#__PURE__*/lazy(() => import('../containers/GalleryView'));
const SelectCollection = /*#__PURE__*/lazy(() => import('../containers/SelectCollection'));
const WindowViewer = /*#__PURE__*/lazy(() => import('../containers/WindowViewer'));
const VideoViewer = /*#__PURE__*/lazy(() => import('../containers/VideoViewer'));
GalleryView.displayName = 'GalleryView';
SelectCollection.displayName = 'SelectCollection';
WindowViewer.displayName = 'WindowViewer';
/**
 * PrimaryWindow - component that renders the primary content of a Mirador
 * window. Right now this differentiates between a Image, Video, or Audio viewer.
 */

export class PrimaryWindow extends Component {
  /**
   * renderViewer - logic used to determine what type of view to show
   *
   * @return {(String|null)}
   */
  renderViewer() {
    const _this$props = this.props,
          audioResources = _this$props.audioResources,
          isCollection = _this$props.isCollection,
          isFetching = _this$props.isFetching,
          videoResources = _this$props.videoResources,
          view = _this$props.view,
          windowId = _this$props.windowId;

    if (isCollection) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(SelectCollection, {
        windowId: windowId
      }));
    }

    if (isFetching === false) {
      if (view === 'gallery') {
        return /*#__PURE__*/React.createElement(GalleryView, {
          windowId: windowId
        });
      }

      if (videoResources.length > 0) {
        return /*#__PURE__*/React.createElement(VideoViewer, {
          windowId: windowId
        });
      }

      if (audioResources.length > 0) {
        return /*#__PURE__*/React.createElement(AudioViewer, {
          windowId: windowId
        });
      }

      return /*#__PURE__*/React.createElement(WindowViewer, {
        windowId: windowId
      });
    }

    return null;
  }
  /**
   * Render the component
   */


  render() {
    const _this$props2 = this.props,
          isCollectionDialogVisible = _this$props2.isCollectionDialogVisible,
          windowId = _this$props2.windowId,
          classes = _this$props2.classes,
          children = _this$props2.children;
    return /*#__PURE__*/React.createElement("div", {
      className: classNames(ns('primary-window'), classes.primaryWindow)
    }, /*#__PURE__*/React.createElement(WindowSideBar, {
      windowId: windowId
    }), /*#__PURE__*/React.createElement(CompanionArea, {
      windowId: windowId,
      position: "left"
    }), isCollectionDialogVisible && /*#__PURE__*/React.createElement(CollectionDialog, {
      windowId: windowId
    }), /*#__PURE__*/React.createElement(Suspense, {
      fallback: /*#__PURE__*/React.createElement("div", null)
    }, children || this.renderViewer()));
  }

}
PrimaryWindow.defaultProps = {
  audioResources: [],
  children: undefined,
  isCollection: false,
  isCollectionDialogVisible: false,
  isFetching: false,
  videoResources: [],
  view: undefined
};