function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import deburr from 'lodash/deburr';
import debounce from 'lodash/debounce';
import isObject from 'lodash/isObject';
import Autocomplete from '@material-ui/lab/Autocomplete';
import CircularProgress from '@material-ui/core/CircularProgress';
import TextField from '@material-ui/core/TextField';
import SearchIcon from '@material-ui/icons/SearchSharp';
import MiradorMenuButton from '../containers/MiradorMenuButton';
import SearchPanelNavigation from '../containers/SearchPanelNavigation';
/** Sometimes an autocomplete match can be a simple string, other times an object
    with a `match` property, this function abstracts that away */

const getMatch = option => isObject(option) ? option.match : option;
/** */


export class SearchPanelControls extends Component {
  /** */
  constructor(props) {
    super(props);
    this.state = {
      search: props.query,
      suggestions: []
    };
    this.handleChange = this.handleChange.bind(this);
    this.submitSearch = this.submitSearch.bind(this);
    this.getSuggestions = this.getSuggestions.bind(this);
    this.selectItem = this.selectItem.bind(this);
    this.fetchAutocomplete = debounce(this.fetchAutocomplete.bind(this), 500);
    this.receiveAutocomplete = this.receiveAutocomplete.bind(this);
  }
  /**
   * Update the query in the component state if the query has changed in the redux store
   */


  componentDidUpdate(prevProps) {
    const query = this.props.query;

    if (query !== prevProps.query) {
      // We are setting local state directly here ONLY when the query prop (from redux)
      // changed
      this.setState({
        // eslint-disable-line react/no-did-update-set-state
        search: query
      });
    }
  }
  /** */


  handleChange(event, value, reason) {
    // For some reason the value gets reset to an empty value from the
    // useAutocomplete hook sometimes, we just ignore these cases
    if (reason === 'reset' && !value) {
      return;
    }

    this.setState({
      search: value,
      suggestions: []
    });

    if (value) {
      this.fetchAutocomplete(value);
    }
  }
  /** */


  getSuggestions(value, {
    showEmpty = false
  } = {}) {
    const suggestions = this.state.suggestions;
    const inputValue = deburr(value.trim()).toLowerCase();
    const inputLength = inputValue.length;
    return inputLength === 0 && !showEmpty ? [] : suggestions;
  }
  /** */


  fetchAutocomplete(value) {
    const autocompleteService = this.props.autocompleteService;
    if (!autocompleteService) return;
    if (!value) return;
    fetch(`${autocompleteService.id}?q=${value}`).then(response => response.json()).then(this.receiveAutocomplete);
  }
  /** */


  receiveAutocomplete(json) {
    this.setState({
      suggestions: json.terms
    });
  }
  /** */


  submitSearch(event) {
    const _this$props = this.props,
          companionWindowId = _this$props.companionWindowId,
          fetchSearch = _this$props.fetchSearch,
          searchService = _this$props.searchService,
          windowId = _this$props.windowId;
    const search = this.state.search;
    event && event.preventDefault();
    if (!search) return;
    fetchSearch(windowId, companionWindowId, `${searchService.id}?q=${search}`, search);
  }
  /** */


  selectItem(_event, selectedItem, _reason) {
    if (selectedItem && getMatch(selectedItem)) {
      this.setState({
        search: getMatch(selectedItem)
      }, this.submitSearch);
    }
  }
  /** */


  render() {
    const _this$props2 = this.props,
          classes = _this$props2.classes,
          companionWindowId = _this$props2.companionWindowId,
          searchIsFetching = _this$props2.searchIsFetching,
          t = _this$props2.t,
          windowId = _this$props2.windowId;
    const _this$state = this.state,
          search = _this$state.search,
          suggestions = _this$state.suggestions;
    const id = `search-${companionWindowId}`;
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("form", {
      onSubmit: this.submitSearch,
      className: classes.form
    }, /*#__PURE__*/React.createElement(Autocomplete, {
      id: id,
      inputValue: search,
      options: suggestions,
      getOptionLabel: getMatch,
      getOptionSelected: (option, value) => deburr(getMatch(option).trim()).toLowerCase() === deburr(getMatch(value).trim()).toLowerCase(),
      noOptionsText: "",
      onChange: this.selectItem,
      onInputChange: this.handleChange,
      freeSolo: true,
      renderInput: params => /*#__PURE__*/React.createElement(TextField, Object.assign({}, params, {
        label: t('searchInputLabel'),
        InputProps: _objectSpread(_objectSpread({}, params.InputProps), {}, {
          endAdornment: /*#__PURE__*/React.createElement("div", {
            className: classes.endAdornment
          }, /*#__PURE__*/React.createElement(MiradorMenuButton, {
            "aria-label": t('searchSubmitAria'),
            type: "submit"
          }, /*#__PURE__*/React.createElement(SearchIcon, null)), Boolean(searchIsFetching) && /*#__PURE__*/React.createElement(CircularProgress, {
            className: classes.searchProgress,
            size: 50
          }))
        })
      }))
    })), /*#__PURE__*/React.createElement(SearchPanelNavigation, {
      windowId: windowId,
      companionWindowId: companionWindowId
    }));
  }

}
SearchPanelControls.defaultProps = {
  autocompleteService: undefined,
  classes: {},
  query: '',
  t: key => key
};