import React, { Component } from 'react';
import Button from '@material-ui/core/Button';
import List from '@material-ui/core/List';
import Typography from '@material-ui/core/Typography';
import BackIcon from '@material-ui/icons/ArrowBackSharp';
import { LiveMessenger } from 'react-aria-live';
import SearchHit from '../containers/SearchHit';
import { ScrollTo } from './ScrollTo';
/** */

export class SearchResults extends Component {
  /** */
  constructor(props) {
    super(props);
    this.state = {
      focused: false
    };
    this.toggleFocus = this.toggleFocus.bind(this);
  }
  /** */


  toggleFocus() {
    const focused = this.state.focused;
    this.setState({
      focused: !focused
    });
  }
  /**
   * Return SearchHits for every hit in the response
   * Return SearchHits for every annotation in the response if there are no hits
   */


  renderSearchHitsAndAnnotations(announcer) {
    const _this$props = this.props,
          companionWindowId = _this$props.companionWindowId,
          containerRef = _this$props.containerRef,
          searchAnnotations = _this$props.searchAnnotations,
          searchHits = _this$props.searchHits,
          windowId = _this$props.windowId;
    const focused = this.state.focused;

    if (searchHits.length === 0 && searchAnnotations.length > 0) {
      return searchAnnotations.map((anno, index) => /*#__PURE__*/React.createElement(SearchHit, {
        announcer: announcer,
        annotationId: anno.id,
        companionWindowId: companionWindowId,
        containerRef: containerRef,
        key: anno.id,
        focused: focused,
        index: index,
        total: searchAnnotations.length,
        windowId: windowId,
        showDetails: this.toggleFocus
      }));
    }

    return searchHits.map((hit, index) => /*#__PURE__*/React.createElement(SearchHit, {
      announcer: announcer,
      containerRef: containerRef,
      companionWindowId: companionWindowId,
      key: hit.annotations[0],
      focused: focused,
      hit: hit,
      index: index,
      total: searchHits.length,
      windowId: windowId,
      showDetails: this.toggleFocus
    }));
  }
  /** */


  render() {
    const _this$props2 = this.props,
          classes = _this$props2.classes,
          companionWindowId = _this$props2.companionWindowId,
          containerRef = _this$props2.containerRef,
          isFetching = _this$props2.isFetching,
          fetchSearch = _this$props2.fetchSearch,
          nextSearch = _this$props2.nextSearch,
          query = _this$props2.query,
          searchAnnotations = _this$props2.searchAnnotations,
          searchHits = _this$props2.searchHits,
          searchNumTotal = _this$props2.searchNumTotal,
          t = _this$props2.t,
          windowId = _this$props2.windowId;
    const focused = this.state.focused;
    const noResultsState = query && !isFetching && searchHits.length === 0 && searchAnnotations.length === 0;
    return /*#__PURE__*/React.createElement(React.Fragment, null, focused && /*#__PURE__*/React.createElement(ScrollTo, {
      containerRef: containerRef,
      offsetTop: 96,
      scrollTo: true
    }, /*#__PURE__*/React.createElement(Button, {
      onClick: this.toggleFocus,
      className: classes.navigation,
      size: "small"
    }, /*#__PURE__*/React.createElement(BackIcon, null), t('backToResults'))), noResultsState && /*#__PURE__*/React.createElement(Typography, {
      className: classes.noResults
    }, t('searchNoResults')), /*#__PURE__*/React.createElement(List, {
      disablePadding: true
    }, /*#__PURE__*/React.createElement(LiveMessenger, null, ({
      announcePolite
    }) => this.renderSearchHitsAndAnnotations(announcePolite))), nextSearch && /*#__PURE__*/React.createElement(Button, {
      className: classes.moreButton,
      color: "secondary",
      onClick: () => fetchSearch(windowId, companionWindowId, nextSearch, query)
    }, t('moreResults'), /*#__PURE__*/React.createElement("br", null), `(${t('searchResultsRemaining', {
      numLeft: searchNumTotal - searchHits.length
    })})`));
  }

}
SearchResults.defaultProps = {
  classes: {},
  containerRef: undefined,
  isFetching: false,
  nextSearch: undefined,
  query: undefined,
  searchAnnotations: [],
  searchHits: [],
  searchNumTotal: undefined,
  t: k => k
};