import React, { Component } from 'react';
import classNames from 'classnames';
import Paper from '@material-ui/core/Paper';
import Typography from '@material-ui/core/Typography';
import ZoomControls from '../containers/ZoomControls';
import ViewerInfo from '../containers/ViewerInfo';
import ViewerNavigation from '../containers/ViewerNavigation';
import ns from '../config/css-ns';
import { PluginHook } from './PluginHook';
/**
 * Represents the viewer controls in the mirador workspace.
 */

export class WindowCanvasNavigationControls extends Component {
  /**
   * Determine if canvasNavControls are stacked (based on a hard-coded width)
  */
  canvasNavControlsAreStacked() {
    const size = this.props.size;
    return size && size.width && size.width <= 253;
  }
  /** */


  render() {
    const _this$props = this.props,
          classes = _this$props.classes,
          visible = _this$props.visible,
          windowId = _this$props.windowId,
          zoomToWorld = _this$props.zoomToWorld;
    if (!visible) return /*#__PURE__*/React.createElement(Typography, {
      variant: "srOnly",
      component: "div"
    }, /*#__PURE__*/React.createElement(ViewerInfo, {
      windowId: windowId
    }));
    return /*#__PURE__*/React.createElement(Paper, {
      square: true,
      className: classNames(classes.controls, ns('canvas-nav'), classes.canvasNav, this.canvasNavControlsAreStacked() ? ns('canvas-nav-stacked') : null, this.canvasNavControlsAreStacked() ? classes.canvasNavStacked : null),
      elevation: 0
    }, /*#__PURE__*/React.createElement(ZoomControls, {
      displayDivider: !this.canvasNavControlsAreStacked(),
      windowId: windowId,
      zoomToWorld: zoomToWorld
    }), /*#__PURE__*/React.createElement(ViewerNavigation, {
      windowId: windowId
    }), /*#__PURE__*/React.createElement(ViewerInfo, {
      windowId: windowId
    }), /*#__PURE__*/React.createElement(PluginHook, this.props));
  }

}
WindowCanvasNavigationControls.defaultProps = {
  classes: {},
  visible: true
};