import React from 'react';
import { Rnd } from 'react-rnd';
import Window from '../containers/Window';
import ns from '../config/css-ns';
/**
 * Represents a work area that contains any number of windows
 * @memberof Workspace
 * @private
 */

class WorkspaceElasticWindow extends React.Component {
  /**
   */
  render() {
    const _this$props = this.props,
          classes = _this$props.classes,
          companionWindowDimensions = _this$props.companionWindowDimensions,
          focused = _this$props.focused,
          layout = _this$props.layout,
          workspace = _this$props.workspace,
          updateElasticWindowLayout = _this$props.updateElasticWindowLayout;
    const offsetX = workspace.width / 2;
    const offsetY = workspace.height / 2;
    return /*#__PURE__*/React.createElement(Rnd, {
      key: `${layout.windowId}-${workspace.id}`,
      size: {
        height: layout.height + companionWindowDimensions.height,
        width: layout.width + companionWindowDimensions.width
      },
      position: {
        x: layout.x + offsetX,
        y: layout.y + offsetY
      },
      bounds: "parent",
      onDragStop: (e, d) => {
        updateElasticWindowLayout(layout.windowId, {
          x: d.x - offsetX,
          y: d.y - offsetY
        });
      },
      onResize: (e, direction, ref, delta, position) => {
        updateElasticWindowLayout(layout.windowId, {
          height: Number.parseInt(ref.style.height, 10) - companionWindowDimensions.height,
          width: Number.parseInt(ref.style.width, 10) - companionWindowDimensions.width,
          x: position.x - offsetX,
          y: position.y - offsetY
        });
      },
      dragHandleClassName: ns('window-top-bar'),
      className: focused ? classes.focused : null
    }, /*#__PURE__*/React.createElement(Window, {
      windowId: layout.windowId
    }));
  }

}

WorkspaceElasticWindow.defaultProps = {
  classes: {},
  companionWindowDimensions: {
    height: 0,
    width: 0
  },
  focused: false
};
export default WorkspaceElasticWindow;