import React, { Component } from 'react';
import ImportIcon from '@material-ui/icons/Input';
import SaveAltIcon from '@material-ui/icons/SaveAltSharp';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import Menu from '@material-ui/core/Menu';
import MenuItem from '@material-ui/core/MenuItem';
import Typography from '@material-ui/core/Typography';
import WorkspaceExport from '../containers/WorkspaceExport';
import WorkspaceImport from '../containers/WorkspaceImport';
import { PluginHook } from './PluginHook';
import ns from '../config/css-ns';
/**
 * WorkspaceOptionsMenu ~ the menu for workspace options such as import/export
*/

export class WorkspaceOptionsMenu extends Component {
  /**
   * constructor -
   */
  constructor(props) {
    super(props);
    this.state = {
      exportWorkspace: {},
      importWorkspace: {}
    };
    this.handleMenuItemClick = this.handleMenuItemClick.bind(this);
    this.handleMenuItemClose = this.handleMenuItemClose.bind(this);
  }
  /**
   * @private
   */


  handleMenuItemClick(item) {
    const obj = {};
    obj[item] = {};
    obj[item].open = true;
    this.setState(obj);
  }
  /**
   * @private
   */


  handleMenuItemClose(item) {
    return event => {
      const obj = {};
      obj[item] = {};
      obj[item].open = false;
      this.setState(obj);
    };
  }
  /**
   * Returns the rendered component
  */


  render() {
    const _this$props = this.props,
          anchorEl = _this$props.anchorEl,
          containerId = _this$props.containerId,
          handleClose = _this$props.handleClose,
          t = _this$props.t;
    const _this$state = this.state,
          exportWorkspace = _this$state.exportWorkspace,
          importWorkspace = _this$state.importWorkspace;
    const container = document.querySelector(`#${containerId} .${ns('viewer')}`);
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Menu, {
      id: "workspace-options-menu",
      container: container,
      anchorEl: anchorEl,
      anchorOrigin: {
        horizontal: 'right',
        vertical: 'top'
      },
      transformOrigin: {
        horizontal: 'left',
        vertical: 'top'
      },
      open: Boolean(anchorEl),
      onClose: handleClose
    }, /*#__PURE__*/React.createElement(MenuItem, {
      "aria-haspopup": "true",
      onClick: () => {
        this.handleMenuItemClick('exportWorkspace');
        handleClose();
      },
      "aria-owns": exportWorkspace.open ? 'workspace-export' : undefined
    }, /*#__PURE__*/React.createElement(ListItemIcon, null, /*#__PURE__*/React.createElement(SaveAltIcon, null)), /*#__PURE__*/React.createElement(Typography, {
      variant: "body1"
    }, t('downloadExportWorkspace'))), /*#__PURE__*/React.createElement(MenuItem, {
      "aria-haspopup": "true",
      id: "workspace-menu-import",
      onClick: () => {
        this.handleMenuItemClick('importWorkspace');
        handleClose();
      },
      "aria-owns": exportWorkspace.open ? 'workspace-import' : undefined
    }, /*#__PURE__*/React.createElement(ListItemIcon, null, /*#__PURE__*/React.createElement(ImportIcon, null)), /*#__PURE__*/React.createElement(Typography, {
      variant: "body1"
    }, t('importWorkspace'))), /*#__PURE__*/React.createElement(PluginHook, this.props)), Boolean(exportWorkspace.open) && /*#__PURE__*/React.createElement(WorkspaceExport, {
      open: Boolean(exportWorkspace.open),
      container: container,
      handleClose: this.handleMenuItemClose('exportWorkspace')
    }), Boolean(importWorkspace.open) && /*#__PURE__*/React.createElement(WorkspaceImport, {
      open: Boolean(importWorkspace.open),
      container: container,
      handleClose: this.handleMenuItemClose('importWorkspace')
    }));
  }

}
WorkspaceOptionsMenu.defaultProps = {
  anchorEl: null
};