import React, { Component } from 'react';
import Dialog from '@material-ui/core/Dialog';
import DialogTitle from '@material-ui/core/DialogTitle';
import { Card, CardContent, MenuList, MenuItem, Typography } from '@material-ui/core';
import WorkspaceTypeElasticIcon from './icons/WorkspaceTypeElasticIcon';
import WorkspaceTypeMosaicIcon from './icons/WorkspaceTypeMosaicIcon';
import ScrollIndicatedDialogContent from '../containers/ScrollIndicatedDialogContent';
/**
 */

export class WorkspaceSelectionDialog extends Component {
  /**
   * Set the initial focus when the dialog enters
   * Find the selected item by using the current workspace type
   * in a selector on the value attribute (which we need to set)
  */
  static setInitialFocus(dialogElement, workspaceType) {
    const selectedListItem = dialogElement.querySelectorAll(`li[value="${workspaceType}"]`);
    if (!selectedListItem || selectedListItem.length === 0) return;
    selectedListItem[0].focus();
  }
  /**
   * constructor
   */


  constructor(props) {
    super(props);
    this.handleWorkspaceTypeChange = this.handleWorkspaceTypeChange.bind(this);
  }
  /**
   * Propagate workspace type selection into the global state
   */


  handleWorkspaceTypeChange(workspaceType) {
    const _this$props = this.props,
          handleClose = _this$props.handleClose,
          updateWorkspace = _this$props.updateWorkspace;
    updateWorkspace({
      type: workspaceType
    });
    handleClose();
  }
  /**
   * render
   * @return
   */


  render() {
    const _this$props2 = this.props,
          classes = _this$props2.classes,
          container = _this$props2.container,
          handleClose = _this$props2.handleClose,
          open = _this$props2.open,
          children = _this$props2.children,
          t = _this$props2.t,
          workspaceType = _this$props2.workspaceType;
    return /*#__PURE__*/React.createElement(Dialog, {
      "aria-labelledby": "workspace-selection-dialog-title",
      container: container,
      id: "workspace-selection-dialog",
      onClose: handleClose,
      onEntered: dialog => WorkspaceSelectionDialog.setInitialFocus(dialog, workspaceType),
      onEscapeKeyDown: handleClose,
      open: open
    }, /*#__PURE__*/React.createElement(DialogTitle, {
      id: "workspace-selection-dialog-title",
      disableTypography: true
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "h2"
    }, t('workspaceSelectionTitle'))), /*#__PURE__*/React.createElement(ScrollIndicatedDialogContent, null, children, /*#__PURE__*/React.createElement(MenuList, {
      classes: {
        root: classes.list
      },
      selected: workspaceType
    }, /*#__PURE__*/React.createElement(MenuItem, {
      className: classes.menuItem,
      onClick: () => this.handleWorkspaceTypeChange('elastic'),
      selected: workspaceType === 'elastic',
      value: "elastic"
    }, /*#__PURE__*/React.createElement(Card, {
      className: classes.card
    }, /*#__PURE__*/React.createElement(WorkspaceTypeElasticIcon, {
      className: classes.svgIcon,
      viewBox: "0 0 120 90"
    }), /*#__PURE__*/React.createElement("div", {
      className: classes.details
    }, /*#__PURE__*/React.createElement(CardContent, {
      classes: {
        root: classes.root
      },
      className: classes.content
    }, /*#__PURE__*/React.createElement(Typography, {
      className: classes.headline,
      component: "p",
      variant: "h3"
    }, t('elastic')), /*#__PURE__*/React.createElement(Typography, {
      variant: "body1"
    }, t('elasticDescription')))))), /*#__PURE__*/React.createElement(MenuItem, {
      className: classes.menuItem,
      onClick: () => this.handleWorkspaceTypeChange('mosaic'),
      selected: workspaceType === 'mosaic',
      value: "mosaic"
    }, /*#__PURE__*/React.createElement(Card, {
      className: classes.card
    }, /*#__PURE__*/React.createElement(WorkspaceTypeMosaicIcon, {
      className: classes.svgIcon,
      viewBox: "0 0 120 90"
    }), /*#__PURE__*/React.createElement("div", {
      className: classes.details
    }, /*#__PURE__*/React.createElement(CardContent, {
      className: classes.content,
      classes: {
        root: classes.root
      }
    }, /*#__PURE__*/React.createElement(Typography, {
      className: classes.headline,
      component: "p",
      variant: "h3"
    }, t('mosaic')), /*#__PURE__*/React.createElement(Typography, {
      variant: "body1"
    }, t('mosaicDescription')))))))));
  }

}
WorkspaceSelectionDialog.defaultProps = {
  children: null,
  container: null,
  open: false,
  t: key => key
};