function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import normalizeUrl from 'normalize-url';
import MiradorCanvas from './MiradorCanvas';
/**
 * CanvasWorld
 */

export default class CanvasWorld {
  /**
   * @param {Array} canvases - Array of Manifesto:Canvas objects to create a
   * world from.
   */
  constructor(canvases, layers, viewingDirection = 'left-to-right') {
    this.canvases = canvases.map(c => new MiradorCanvas(c));
    this.layers = layers;
    this.viewingDirection = viewingDirection;
    this._canvasDimensions = null; // eslint-disable-line no-underscore-dangle
  }
  /** */


  get canvasIds() {
    return this.canvases.map(canvas => canvas.id);
  }
  /** */


  get canvasDimensions() {
    if (this._canvasDimensions) {
      // eslint-disable-line no-underscore-dangle
      return this._canvasDimensions; // eslint-disable-line no-underscore-dangle
    }

    const _this$canvasDirection = _slicedToArray(this.canvasDirection, 2),
          dirX = _this$canvasDirection[0],
          dirY = _this$canvasDirection[1];

    const scale = dirY === 0 ? Math.min(...this.canvases.map(c => c.getHeight())) : Math.min(...this.canvases.map(c => c.getWidth()));
    let incX = 0;
    let incY = 0;
    const canvasDims = this.canvases.reduce((acc, canvas) => {
      let canvasHeight = 0;
      let canvasWidth = 0;

      if (!isNaN(canvas.aspectRatio)) {
        if (dirY === 0) {
          // constant height
          canvasHeight = scale;
          canvasWidth = Math.floor(scale * canvas.aspectRatio);
        } else {
          // constant width
          canvasWidth = scale;
          canvasHeight = Math.floor(scale * (1 / canvas.aspectRatio));
        }
      }

      acc.push({
        canvas,
        height: canvasHeight,
        width: canvasWidth,
        x: incX,
        y: incY
      });
      incX += dirX * canvasWidth;
      incY += dirY * canvasHeight;
      return acc;
    }, []);
    const worldHeight = dirY === 0 ? scale : Math.abs(incY);
    const worldWidth = dirX === 0 ? scale : Math.abs(incX);
    this._canvasDimensions = canvasDims // eslint-disable-line no-underscore-dangle
    .reduce((acc, dims) => {
      acc.push(_objectSpread(_objectSpread({}, dims), {}, {
        x: dirX === -1 ? dims.x + worldWidth - dims.width : dims.x,
        y: dirY === -1 ? dims.y + worldHeight - dims.height : dims.y
      }));
      return acc;
    }, []);
    return this._canvasDimensions; // eslint-disable-line no-underscore-dangle
  }
  /**
   * contentResourceToWorldCoordinates - calculates the contentResource coordinates
   * respective to the world.
   */


  contentResourceToWorldCoordinates(contentResource) {
    const miradorCanvasIndex = this.canvases.findIndex(c => c.imageResources.find(r => r.id === contentResource.id));
    const canvas = this.canvases[miradorCanvasIndex];
    if (!canvas) return [];

    const _this$canvasToWorldCo = this.canvasToWorldCoordinates(canvas.id),
          _this$canvasToWorldCo2 = _slicedToArray(_this$canvasToWorldCo, 4),
          x = _this$canvasToWorldCo2[0],
          y = _this$canvasToWorldCo2[1],
          w = _this$canvasToWorldCo2[2],
          h = _this$canvasToWorldCo2[3];

    const fragmentOffset = canvas.onFragment(contentResource.id);

    if (fragmentOffset) {
      return [x + fragmentOffset[0], y + fragmentOffset[1], fragmentOffset[2], fragmentOffset[3]];
    }

    return [x, y, w, h];
  }
  /** */


  canvasToWorldCoordinates(canvasId) {
    const canvasDimensions = this.canvasDimensions.find(c => c.canvas.id === canvasId);
    return [canvasDimensions.x, canvasDimensions.y, canvasDimensions.width, canvasDimensions.height];
  }
  /** */


  get canvasDirection() {
    switch (this.viewingDirection) {
      case 'left-to-right':
        return [1, 0];

      case 'right-to-left':
        return [-1, 0];

      case 'top-to-bottom':
        return [0, 1];

      case 'bottom-to-top':
        return [0, -1];

      default:
        return [1, 0];
    }
  }
  /** Get the IIIF content resource for an image */


  contentResource(infoResponseId) {
    const miradorCanvas = this.canvases.find(c => c.imageServiceIds.some(id => normalizeUrl(id, {
      stripAuthentication: false
    }) === normalizeUrl(infoResponseId, {
      stripAuthentication: false
    })));
    if (!miradorCanvas) return undefined;
    return miradorCanvas.imageResources.find(r => normalizeUrl(r.getServices()[0].id, {
      stripAuthentication: false
    }) === normalizeUrl(infoResponseId, {
      stripAuthentication: false
    }));
  }
  /** @private */


  getLayerMetadata(contentResource) {
    if (!this.layers) return undefined;
    const miradorCanvas = this.canvases.find(c => c.imageResources.find(r => r.id === contentResource.id));
    if (!miradorCanvas) return undefined;
    const resourceIndex = miradorCanvas.imageResources.findIndex(r => r.id === contentResource.id);
    const layer = this.layers[miradorCanvas.canvas.id];
    const imageResourceLayer = layer && layer[contentResource.id];
    return _objectSpread({
      index: resourceIndex,
      opacity: 1,
      total: miradorCanvas.imageResources.length,
      visibility: true
    }, imageResourceLayer);
  }
  /** */


  layerOpacityOfImageResource(contentResource) {
    const layer = this.getLayerMetadata(contentResource);
    if (!layer) return 1;
    if (!layer.visibility) return 0;
    return layer.opacity;
  }
  /** */


  layerIndexOfImageResource(contentResource) {
    const layer = this.getLayerMetadata(contentResource);
    if (!layer) return undefined;
    return layer.total - layer.index - 1;
  }
  /**
   * offsetByCanvas - calculates the offset for a given canvas target. Currently
   * assumes a horrizontal only layout.
   */


  offsetByCanvas(canvasTarget) {
    const coordinates = this.canvasToWorldCoordinates(canvasTarget);
    return {
      x: coordinates[0],
      y: coordinates[1]
    };
  }
  /**
   * worldBounds - calculates the "World" bounds. World in this case is canvases
   * lined up horizontally starting from left to right.
   */


  worldBounds() {
    const worldWidth = Math.max(...this.canvasDimensions.map(c => c.x + c.width));
    const worldHeight = Math.max(...this.canvasDimensions.map(c => c.y + c.height));
    return [0, 0, worldWidth, worldHeight];
  }
  /** */


  canvasAtPoint(point) {
    const canvasDimensions = this.canvasDimensions.find(c => c.x <= point.x && point.x <= c.x + c.width && c.y <= point.y && point.y <= c.y + c.height);
    return canvasDimensions && canvasDimensions.canvas;
  }

}