import _regeneratorRuntime from "@babel/runtime/regenerator";

var _marked = /*#__PURE__*/_regeneratorRuntime.mark(fetchCanvasAnnotations),
    _marked2 = /*#__PURE__*/_regeneratorRuntime.mark(fetchAnnotations),
    _marked3 = /*#__PURE__*/_regeneratorRuntime.mark(appSaga);

import { all, put, select, takeEvery } from 'redux-saga/effects';
import { requestCanvasAnnotations, receiveAnnotation, requestAnnotation } from '../actions';
import { getAnnotations, getCanvas } from '../selectors';
import ActionTypes from '../actions/action-types';
import MiradorCanvas from '../../lib/MiradorCanvas';
/** Fetch annotations for a given canvas */

export function fetchCanvasAnnotations({
  canvasId,
  windowId
}) {
  var canvas, annotations, miradorCanvas;
  return _regeneratorRuntime.wrap(function fetchCanvasAnnotations$(_context) {
    while (1) switch (_context.prev = _context.next) {
      case 0:
        _context.next = 2;
        return select(getCanvas, {
          canvasId,
          windowId
        });

      case 2:
        canvas = _context.sent;
        _context.next = 5;
        return select(getAnnotations);

      case 5:
        annotations = _context.sent;
        miradorCanvas = new MiradorCanvas(canvas);
        _context.next = 9;
        return all([// IIIF v2
        ...miradorCanvas.annotationListUris.filter(uri => !(annotations[canvas.id] && annotations[canvas.id][uri])).map(uri => put(requestAnnotation(canvas.id, uri))), // IIIF v3
        ...miradorCanvas.canvasAnnotationPages.filter(annotation => !(annotations[canvas.id] && annotations[canvas.id][annotation.id])).map(annotation => {
          // If there are no items, try to retrieve the referenced resource.
          // otherwise the resource should be embedded and just add to the store.
          if (!annotation.items) {
            return put(requestAnnotation(canvas.id, annotation.id));
          }

          return put(receiveAnnotation(canvas.id, annotation.id, annotation));
        })]);

      case 9:
        return _context.abrupt("return", _context.sent);

      case 10:
      case "end":
        return _context.stop();
    }
  }, _marked);
}
/**
 * Fetch annotations for the visible canvases.
 */

export function fetchAnnotations({
  visibleCanvases = [],
  windowId
}) {
  return _regeneratorRuntime.wrap(function fetchAnnotations$(_context2) {
    while (1) switch (_context2.prev = _context2.next) {
      case 0:
        _context2.next = 2;
        return all(visibleCanvases.map(canvasId => put(requestCanvasAnnotations(windowId, canvasId))));

      case 2:
        return _context2.abrupt("return", _context2.sent);

      case 3:
      case "end":
        return _context2.stop();
    }
  }, _marked2);
}
/** */

export default function appSaga() {
  return _regeneratorRuntime.wrap(function appSaga$(_context3) {
    while (1) switch (_context3.prev = _context3.next) {
      case 0:
        _context3.next = 2;
        return all([takeEvery(ActionTypes.REQUEST_CANVAS_ANNOTATIONS, fetchCanvasAnnotations), takeEvery(ActionTypes.SET_CANVAS, fetchAnnotations)]);

      case 2:
      case "end":
        return _context3.stop();
    }
  }, _marked3);
}