import _regeneratorRuntime from "@babel/runtime/regenerator";

var _marked = /*#__PURE__*/_regeneratorRuntime.mark(refetchInfoResponsesOnLogout),
    _marked2 = /*#__PURE__*/_regeneratorRuntime.mark(refetchInfoResponses),
    _marked3 = /*#__PURE__*/_regeneratorRuntime.mark(doAuthWorkflow),
    _marked4 = /*#__PURE__*/_regeneratorRuntime.mark(rerequestOnAccessTokenFailure),
    _marked5 = /*#__PURE__*/_regeneratorRuntime.mark(invalidateInvalidAuth),
    _marked6 = /*#__PURE__*/_regeneratorRuntime.mark(authSaga);

import { all, call, put, select, takeEvery, delay } from 'redux-saga/effects';
import { Utils } from 'manifesto.js/dist-esmodule/Utils';
import flatten from 'lodash/flatten';
import ActionTypes from '../actions/action-types';
import MiradorCanvas from '../../lib/MiradorCanvas';
import { addAuthenticationRequest, resolveAuthenticationRequest, requestAccessToken, resetAuthenticationState } from '../actions';
import { selectInfoResponses, getVisibleCanvases, getWindows, getConfig, getAuth, getAccessTokens } from '../selectors';
import { fetchInfoResponse } from './iiif';
/** */

export function refetchInfoResponsesOnLogout({
  tokenServiceId
}) {
  return _regeneratorRuntime.wrap(function refetchInfoResponsesOnLogout$(_context) {
    while (1) switch (_context.prev = _context.next) {
      case 0:
        _context.next = 2;
        return delay(2000);

      case 2:
        _context.next = 4;
        return call(refetchInfoResponses, {
          serviceId: tokenServiceId
        });

      case 4:
      case "end":
        return _context.stop();
    }
  }, _marked);
}
/**
 * Figure out what info responses could have used the access token service and:
 *   - refetch, if they are currently visible
 *   - throw them out (and lazy re-fetch) otherwise
 */

export function refetchInfoResponses({
  serviceId
}) {
  var windows, canvases, visibleImageApiIds, infoResponses, haveThisTokenService, obsoleteInfoResponses;
  return _regeneratorRuntime.wrap(function refetchInfoResponses$(_context2) {
    while (1) switch (_context2.prev = _context2.next) {
      case 0:
        _context2.next = 2;
        return select(getWindows);

      case 2:
        windows = _context2.sent;
        _context2.next = 5;
        return all(Object.keys(windows).map(windowId => select(getVisibleCanvases, {
          windowId
        })));

      case 5:
        canvases = _context2.sent;
        visibleImageApiIds = flatten(flatten(canvases).map(canvas => {
          const miradorCanvas = new MiradorCanvas(canvas);
          return miradorCanvas.imageServiceIds;
        }));
        _context2.next = 9;
        return select(selectInfoResponses);

      case 9:
        infoResponses = _context2.sent;

        /** */
        haveThisTokenService = infoResponse => {
          const services = Utils.getServices(infoResponse);
          return services.some(e => {
            const infoTokenService = Utils.getService(e, 'http://iiif.io/api/auth/1/token') || Utils.getService(e, 'http://iiif.io/api/auth/0/token');
            return infoTokenService && infoTokenService.id === serviceId;
          });
        };

        obsoleteInfoResponses = Object.values(infoResponses).filter(i => i.json && haveThisTokenService(i.json));
        _context2.next = 14;
        return all(obsoleteInfoResponses.map(({
          id: infoId
        }) => {
          if (visibleImageApiIds.includes(infoId)) {
            return call(fetchInfoResponse, {
              infoId
            });
          }

          return put({
            infoId,
            type: ActionTypes.REMOVE_INFO_RESPONSE
          });
        }));

      case 14:
      case "end":
        return _context2.stop();
    }
  }, _marked2);
}
/** try to start any non-interactive auth flows */

export function doAuthWorkflow({
  infoJson,
  windowId
}) {
  var auths, _yield$select, _yield$select$auth, _yield$select$auth2, _yield$select$auth2$s, serviceProfiles, nonInteractiveAuthFlowProfiles, authService, profileConfig, tokenService;

  return _regeneratorRuntime.wrap(function doAuthWorkflow$(_context3) {
    while (1) switch (_context3.prev = _context3.next) {
      case 0:
        _context3.next = 2;
        return select(getAuth);

      case 2:
        auths = _context3.sent;
        _context3.next = 5;
        return select(getConfig);

      case 5:
        _yield$select = _context3.sent;
        _yield$select$auth = _yield$select.auth;
        _yield$select$auth2 = _yield$select$auth === void 0 ? {} : _yield$select$auth;
        _yield$select$auth2$s = _yield$select$auth2.serviceProfiles;
        serviceProfiles = _yield$select$auth2$s === void 0 ? [] : _yield$select$auth2$s;
        nonInteractiveAuthFlowProfiles = serviceProfiles.filter(p => p.external || p.kiosk); // try to get an untried, non-interactive auth service

        authService = Utils.getServices(infoJson).filter(s => !auths[s.id]).find(e => nonInteractiveAuthFlowProfiles.some(p => p.profile === e.getProfile()));

        if (authService) {
          _context3.next = 14;
          break;
        }

        return _context3.abrupt("return");

      case 14:
        profileConfig = nonInteractiveAuthFlowProfiles.find(p => p.profile === authService.getProfile());

        if (!profileConfig.kiosk) {
          _context3.next = 20;
          break;
        }

        _context3.next = 18;
        return put(addAuthenticationRequest(windowId, authService.id, authService.getProfile()));

      case 18:
        _context3.next = 28;
        break;

      case 20:
        if (!profileConfig.external) {
          _context3.next = 28;
          break;
        }

        tokenService = Utils.getService(authService, 'http://iiif.io/api/auth/1/token') || Utils.getService(authService, 'http://iiif.io/api/auth/0/token');

        if (tokenService) {
          _context3.next = 24;
          break;
        }

        return _context3.abrupt("return");

      case 24:
        _context3.next = 26;
        return put(resolveAuthenticationRequest(authService.id, tokenService.id));

      case 26:
        _context3.next = 28;
        return put(requestAccessToken(tokenService.id, authService.id));

      case 28:
      case "end":
        return _context3.stop();
    }
  }, _marked3);
}
/** */

export function rerequestOnAccessTokenFailure({
  infoJson,
  windowId,
  tokenServiceId
}) {
  var authService, accessTokenServices, service;
  return _regeneratorRuntime.wrap(function rerequestOnAccessTokenFailure$(_context4) {
    while (1) switch (_context4.prev = _context4.next) {
      case 0:
        if (tokenServiceId) {
          _context4.next = 2;
          break;
        }

        return _context4.abrupt("return");

      case 2:
        // make sure we have an auth service to try
        authService = Utils.getServices(infoJson).find(service => {
          const tokenService = Utils.getService(service, 'http://iiif.io/api/auth/1/token') || Utils.getService(service, 'http://iiif.io/api/auth/0/token');
          return tokenService && tokenService.id === tokenServiceId;
        });

        if (authService) {
          _context4.next = 5;
          break;
        }

        return _context4.abrupt("return");

      case 5:
        _context4.next = 7;
        return select(getAccessTokens);

      case 7:
        accessTokenServices = _context4.sent;
        service = accessTokenServices[tokenServiceId];

        if (service && service.success) {
          _context4.next = 11;
          break;
        }

        return _context4.abrupt("return");

      case 11:
        _context4.next = 13;
        return put(requestAccessToken(tokenServiceId, authService.id));

      case 13:
      case "end":
        return _context4.stop();
    }
  }, _marked4);
}
/** */

export function invalidateInvalidAuth({
  serviceId
}) {
  var accessTokenServices, authServices, accessTokenService, authService;
  return _regeneratorRuntime.wrap(function invalidateInvalidAuth$(_context5) {
    while (1) switch (_context5.prev = _context5.next) {
      case 0:
        _context5.next = 2;
        return select(getAccessTokens);

      case 2:
        accessTokenServices = _context5.sent;
        _context5.next = 5;
        return select(getAuth);

      case 5:
        authServices = _context5.sent;
        accessTokenService = accessTokenServices[serviceId];

        if (accessTokenService) {
          _context5.next = 9;
          break;
        }

        return _context5.abrupt("return");

      case 9:
        authService = authServices[accessTokenService.authId];

        if (authService) {
          _context5.next = 12;
          break;
        }

        return _context5.abrupt("return");

      case 12:
        if (!accessTokenService.success) {
          _context5.next = 17;
          break;
        }

        _context5.next = 15;
        return put(resetAuthenticationState({
          authServiceId: authService.id,
          tokenServiceId: accessTokenService.id
        }));

      case 15:
        _context5.next = 19;
        break;

      case 17:
        _context5.next = 19;
        return put(resolveAuthenticationRequest(authService.id, accessTokenService.id, {
          ok: false
        }));

      case 19:
      case "end":
        return _context5.stop();
    }
  }, _marked5);
}
/** */

export default function authSaga() {
  return _regeneratorRuntime.wrap(function authSaga$(_context6) {
    while (1) switch (_context6.prev = _context6.next) {
      case 0:
        _context6.next = 2;
        return all([takeEvery(ActionTypes.RECEIVE_DEGRADED_INFO_RESPONSE, rerequestOnAccessTokenFailure), takeEvery(ActionTypes.RECEIVE_ACCESS_TOKEN_FAILURE, invalidateInvalidAuth), takeEvery(ActionTypes.RECEIVE_DEGRADED_INFO_RESPONSE, doAuthWorkflow), takeEvery(ActionTypes.RECEIVE_ACCESS_TOKEN, refetchInfoResponses), takeEvery(ActionTypes.RESET_AUTHENTICATION_STATE, refetchInfoResponsesOnLogout)]);

      case 2:
      case "end":
        return _context6.stop();
    }
  }, _marked6);
}