function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { createSelector } from 'reselect';
import { getManifestTitle } from './manifests';
import { getConfig } from './config';
import { getWindows, getWindow, getWindowIds } from './getters';
import { getWorkspaceType } from './workspace';
import { getSequenceViewingHint, getSequenceBehaviors } from './sequences';
/** */

export const getWindowConfig = createSelector([getConfig, getWindow], ({
  window: defaultConfig
}, windowConfig = {}) => _objectSpread(_objectSpread({}, defaultConfig), windowConfig));
/**
 * Return the manifest titles for all open windows
 * @param {object} state
 * @return {object}
 */

export function getWindowTitles(state) {
  const result = {};
  Object.keys(getWindows(state)).forEach(windowId => {
    result[windowId] = getManifestTitle(state, {
      windowId
    });
  });
  return result;
}
/** */

export const getMaximizedWindowsIds = createSelector([getWindows], windows => Object.values(windows).filter(window => window.maximized === true).map(window => window.id));
/** Return type of view in a certain window.
* @param {object} state
* @param {object} props
* @param {string} props.manifestId
* @param {string} props.windowId
* @param {String}
*/

export const getWindowViewType = createSelector([getWindow, getWindowConfig, getSequenceViewingHint, getSequenceBehaviors], (window, {
  views = [],
  defaultView
}, manifestViewingHint, manifestBehaviors) => {
  if (window && window.view) return window.view;
  const config = (views || []).find(view => view.behaviors && view.behaviors.some(b => manifestViewingHint === b || manifestBehaviors.includes(b)));
  return config && config.key || defaultView;
});
/** */

export const getAllowedWindowViewTypes = createSelector([getSequenceViewingHint, getSequenceBehaviors, getWindowConfig], (manifestViewingHint, manifestBehaviors, {
  views = [],
  defaultView
}) => (views || []).reduce((allowedViews, view) => {
  if (view.key === defaultView || !view.behaviors || view.behaviors.some(b => manifestViewingHint === b || manifestBehaviors.includes(b))) allowedViews.push(view.key);
  return allowedViews;
}, []));
/**
 * Returns the draggability of a window
 * @param {object} state
 * @param {object} props
 * @return {Boolean}
 */

export const getWindowDraggability = createSelector([getWorkspaceType, getWindow, state => getWindowIds(state).length > 1], (workspaceType, window, manyWindows) => {
  if (workspaceType === 'elastic') return true;
  return manyWindows && window && window.maximized === false;
});